% Auto-generated chapter 43 for tirmidhi
% Hadiths in this chapter: 138

\hadithdefcmd{tirmidhi}{2736}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِلْمُسْلِمِ عَلَى الْمُسْلِمِ سِتٌّ بِالْمَعْرُوفِ يُسَلِّمُ عَلَيْهِ إِذَا لَقِيَهُ وَيُجِيبُهُ إِذَا دَعَاهُ وَيُشَمِّتُهُ إِذَا عَطَسَ وَيَعُودُهُ إِذَا مَرِضَ وَيَتْبَعُ جَنَازَتَهُ إِذَا مَاتَ وَيُحِبُّ لَهُ مَا يُحِبُّ لِنَفْسِهِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَبِي أَيُّوبَ وَالْبَرَاءِ وَأَبِي مَسْعُودٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُهُمْ فِي الْحَارِثِ الأَعْوَرِ ‏.‏\hadithno{2736}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ali:that the Messenger of Allah (ﷺ) said: "There are six courtesies due from a Muslim to another Muslim: To give Salam to him when he meets him, to accept his invitation when he invites him, to reply to him when he sneezes, to visit him when he is ill, to follow his funeral when he dies, and to love for him what he loves for himself}}
\hadithdefcmd{tirmidhi}{2737}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى الْمَخْزُومِيُّ الْمَدَنِيُّ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِلْمُؤْمِنِ عَلَى الْمُؤْمِنِ سِتُّ خِصَالٍ يَعُودُهُ إِذَا مَرِضَ وَيَشْهَدُهُ إِذَا مَاتَ وَيُجِيبُهُ إِذَا دَعَاهُ وَيُسَلِّمُ عَلَيْهِ إِذَا لَقِيَهُ وَيُشَمِّتُهُ إِذَا عَطَسَ وَيَنْصَحُ لَهُ إِذَا غَابَ أَوْ شَهِدَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَمُحَمَّدُ بْنُ مُوسَى الْمَخْزُومِيُّ الْمَدَنِيُّ ثِقَةٌ رَوَى عَنْهُ عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ وَابْنُ أَبِي فُدَيْكٍ ‏.‏\hadithno{2737}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "There are six things due from the believer to another believer: Visiting him when he is ill, attending (his funeral) to him when he dies, accepting his invitation when he invites, giving him Salam when he meets him, replying to him when he sneezes, and wishing him well when he is absent and when he is present}}
\hadithdefcmd{tirmidhi}{2738}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا زِيَادُ بْنُ الرَّبِيعِ، حَدَّثَنَا حَضْرَمِيٌّ، مَوْلَى آلِ الْجَارُودِ عَنْ نَافِعٍ، أَنَّ رَجُلاً، عَطَسَ إِلَى جَنْبِ ابْنِ عُمَرَ فَقَالَ الْحَمْدُ لِلَّهِ وَالسَّلاَمُ عَلَى رَسُولِ اللَّهِ ‏.‏ قَالَ ابْنُ عُمَرَ وَأَنَا أَقُولُ الْحَمْدُ لِلَّهِ وَالسَّلاَمُ عَلَى رَسُولِ اللَّهِ وَلَيْسَ هَكَذَا عَلَّمَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَّمَنَا أَنْ نَقُولَ الْحَمْدُ لِلَّهِ عَلَى كُلِّ حَالٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ زِيَادِ بْنِ الرَّبِيعِ ‏.‏\hadithno{2738}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Hadrami, the freed slave of the family of Al-Jarud:from Nafi: "A man sneezed beside Ibn 'Umar and said: 'Al-Hamdulillah Was-Salamu 'Ala Rasulillah. (All praise is due to Allah, and peace upon the Messenger of Allah)'. So Ibn 'Umar said: 'I too say Al-Hamdulillah Was-Salamu 'Ala Rasulillah, but this is not what the Messenger of Allah (ﷺ) taught us. He taught us to say: "Al-Hamdulillah 'Ala Kulli Hal (All praise is due to Allah in every circumstance)}}
\hadithdefcmd{tirmidhi}{2739}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ حَكِيمِ بْنِ دَيْلَمَ، عَنْ أَبِي بُرْدَةَ بْنِ أَبِي مُوسَى، عَنْ أَبِي مُوسَى، قَالَ كَانَ الْيَهُودُ يَتَعَاطَسُونَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم يَرْجُونَ أَنْ يَقُولَ لَهُمْ يَرْحَمُكُمُ اللَّهُ ‏.‏ فَيَقُولُ ‏ "‏ يَهْدِيكُمُ اللَّهُ وَيُصْلِحُ بَالَكُمْ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي أَيُّوبَ وَسَالِمِ بْنِ عُبَيْدٍ وَعَبْدِ اللَّهِ بْنِ جَعْفَرٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2739}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Musa:The Jews used to sneeze in the presence of the Prophet (ﷺ) hoping that he would say: 'Yarhamukumullah (May Allah have mercy upon you).' So he said: 'Yahdikumullahu Wa Yuslihu Balakum (May Allah guide you and rectify your affairs)}}
\hadithdefcmd{tirmidhi}{2740}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ سَالِمِ بْنِ عُبَيْدٍ، أَنَّهُ كَانَ مَعَ الْقَوْمِ فِي سَفَرٍ فَعَطَسَ رَجُلٌ مِنَ الْقَوْمِ فَقَالَ السَّلاَمُ عَلَيْكُمْ ‏.‏ فَقَالَ عَلَيْكَ وَعَلَى أُمِّكَ فَكَأَنَّ الرَّجُلَ وَجِدَ فِي نَفْسِهِ فَقَالَ أَمَا إِنِّي لَمْ أَقُلْ إِلاَّ مَا قَالَ النَّبِيُّ صلى الله عليه وسلم عَطَسَ رَجُلٌ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ السَّلاَمُ عَلَيْكُمْ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ عَلَيْكَ وَعَلَى أُمِّكَ إِذَا عَطَسَ أَحَدُكُمْ فَلْيَقُلِ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ وَلْيَقُلْ لَهُ مَنْ يَرُدُّ عَلَيْهِ يَرْحَمُكَ اللَّهُ وَلْيَقُلْ يَغْفِرُ اللَّهُ لَنَا وَلَكُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ اخْتَلَفُوا فِي رِوَايَتِهِ عَنْ مَنْصُورٍ وَقَدْ أَدْخَلُوا بَيْنَ هِلاَلِ بْنِ يِسَافٍ وَسَالِمٍ رَجُلاً ‏.‏\hadithno{2740}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Salim bin 'Ubaid:that he was with some people on a journey, and a man among the people sneezed and he said: "As-Salamu Alaikum (peace be upon you)." So he (Salim) said: "'Alaika Wa 'Ala Ummik (upon you and upon your mother)." It seemed as if that bothered the man, so he said: "Indeed I have not said except what the Prophet (ﷺ) said; a man sneezed in the presence of the Prophet (ﷺ) and said: 'As-Salamu 'Alaikum (peace be upon you)' so the Prophet (ﷺ) said: ''Alaika Wa 'Ala Ummik (upon you and upon your mother). When one of you sneezes let him say: "Al-Hamdulillahi Rabbil-'Alamin (All praise is due to the Lord of all that exists)" and let the one responding to him say: Yarhamukallah (May Allah have mercy upon you)" and let him reply: Yaghfirullah Li Walakum (May Allah forgive me and you both)}}
\hadithdefcmd{tirmidhi}{2741}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَخْبَرَنَا شُعْبَةُ، أَخْبَرَنِي ابْنُ أَبِي لَيْلَى، عَنْ أَخِيهِ، عِيسَى بْنِ عَبْدِ الرَّحْمَنِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ أَبِي أَيُّوبَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا عَطَسَ أَحَدُكُمْ فَلْيَقُلِ الْحَمْدُ لِلَّهِ عَلَى كُلِّ حَالٍ وَلْيَقُلِ الَّذِي يَرُدُّ عَلَيْهِ يَرْحَمُكَ اللَّهُ وَلْيَقُلْ هُوَ يَهْدِيكُمُ اللَّهُ وَيُصْلِحُ بَالَكُمْ ‏"‏ ‏.‏\hadithno{2741}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Ayyub:that the Messenger of Allah (ﷺ) said: "When one of you sneezes let him say: 'Al-Hamdulillahi 'Ala Kulli Hal (All praise is due to Allah in every circumstance).' And let the one replying to him say: "Yarhamukallah (May Allah have mercy upon you).' And let him say to him: 'Yahdikumullah Wa Yuslihu Balakum (May Allah guide you and rectify your affairs)}}
\hadithdefcmd{tirmidhi}{2741p2}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ ابْنِ أَبِي لَيْلَى، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ قَالَ هَكَذَا رَوَى شُعْبَةُ، هَذَا الْحَدِيثَ عَنِ ابْنِ أَبِي لَيْلَى، عَنْ أَبِي أَيُّوبَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَكَانَ ابْنُ أَبِي لَيْلَى يَضْطَرِبُ فِي هَذَا الْحَدِيثِ يَقُولُ أَحْيَانًا عَنْ أَبِي أَيُّوبَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَيَقُولُ أَحْيَانًا عَنْ عَلِيٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2741.2}\hadithtrans{(Another chain) with similar narration. He [At-Tirmidhi] said:This is how Shu'bah reported this Hadith from IbnAbi Laila, and he said: "From Abu Ayyub from the Prophet (ﷺ)." Ibn Abi Laila was confused in this narration, sometimes he would say: "From Abu Ayyub from the Prophet (ﷺ)" and sometimes he would say: "From 'Ali from the Prophet (ﷺ)" similarly in meaning}}
\hadithdefcmd{tirmidhi}{2741p3}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ يَحْيَى الثَّقَفِيُّ الْمَرْوَزِيُّ، قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ أَخِيهِ، عِيسَى عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَلِيٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{2741.3}\hadithtrans{(Another chain) from 'Ali from the Prophet (ﷺ) with similar meaning}}
\hadithdefcmd{tirmidhi}{2742}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلَيْنِ، عَطَسَا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَشَمَّتَ أَحَدَهُمَا وَلَمْ يُشَمِّتِ الآخَرَ فَقَالَ الَّذِي لَمْ يُشَمِّتْهُ يَا رَسُولَ اللَّهِ شَمَّتَّ هَذَا وَلَمْ تُشَمِّتْنِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّهُ حَمِدَ اللَّهَ وَإِنَّكَ لَمْ تَحْمَدِ اللَّهَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2742}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas bin Malik:that two men sneezed in the presence of the Prophet (ﷺ); he responded to one of them and did not respond to the other. The one who was not responded to said: "O Messenger of Allah! You responded to this person and did not respond to me?' So the Messenger of Allah (ﷺ) said: "He praised Allah while you did not praise Him}}
\hadithdefcmd{tirmidhi}{2743}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، عَنْ إِيَاسِ بْنِ سَلَمَةَ بْنِ الأَكْوَعِ، عَنْ أَبِيهِ، قَالَ عَطَسَ رَجُلٌ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا شَاهِدٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَرْحَمُكَ اللَّهُ ‏"‏ ‏.‏ ثُمَّ عَطَسَ الثَّانِيَةَ وَالثَّالِثَةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذَا رَجُلٌ مَزْكُومٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2743}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Iyas bin Salamah:from his father: "A man sneezed in the presence of the Messenger of Allah (ﷺ) while I was present, so the Messenger of Allah (ﷺ) said: 'Yarhamukallah (May Allah have mercy upon you).' Then he sneezed a second and third time. So the Messenger of Allah (ﷺ) said: "This man is suffering from a cold}}
\hadithdefcmd{tirmidhi}{2743p2}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، عَنْ إِيَاسِ بْنِ سَلَمَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ إِلاَّ أَنَّهُ قَالَ لَهُ فِي الثَّالِثَةِ ‏ "‏ أَنْتَ مَزْكُومٌ ‏"‏ ‏.‏ قَالَ هَذَا أَصَحُّ مِنْ حَدِيثِ ابْنِ الْمُبَارَكِ ‏.‏\hadithno{2743.2}\hadithtrans{(Another chain) from Iyas bin Salamah from his father, from the Prophet (ﷺ) with similar narration, except that he said to him the third time:"You are suffering from a cold." [He said:] And this is more correct than the narration of Ibn Al-Mubarak}}
\hadithdefcmd{tirmidhi}{2743p3}{وَقَدْ رَوَى شُعْبَةُ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، هَذَا الْحَدِيثَ نَحْوَ رِوَايَةِ يَحْيَى بْنِ سَعِيدٍ حَدَّثَنَا بِذَلِكَ، أَحْمَدُ بْنُ الْحَكَمِ الْبَصْرِيُّ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، بِهَذَا ‏.‏\hadithno{2743.3}\hadithtrans{Shu'bah reported this Hadith from 'Ikrimah bin 'Ammar and it is similar to the narration of Yahya bin Sa'eed. (A chain to support that)}}
\hadithdefcmd{tirmidhi}{2743p4}{وَرَوَى عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، نَحْوَ رِوَايَةِ ابْنِ الْمُبَارَكِ وَقَالَ لَهُ فِي الثَّالِثَةِ ‏ "‏ أَنْتَ مَزْكُومٌ ‏"‏ ‏.‏ حَدَّثَنَا بِذَلِكَ إِسْحَاقُ بْنُ مَنْصُورٍ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ ‏.‏\hadithno{2743.4}\hadithtrans{And 'Abdur-Rahman bin Mahdi reported it from 'Ikrimah bin 'Ammar and it is similar to the narration of Ibn Al-Mubarak, but he said to him the third time:"You are suffering from a cold." (A chain to support that)}}
\hadithdefcmd{tirmidhi}{2744}{حَدَّثَنَا الْقَاسِمُ بْنُ دِينَارٍ الْكُوفِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ السَّلُولِيُّ الْكُوفِيُّ، عَنْ عَبْدِ السَّلاَمِ بْنِ حَرْبٍ، عَنْ يَزِيدَ بْنِ عَبْدِ الرَّحْمَنِ أَبِي خَالِدٍ الدَّالاَنِيِّ، عَنْ عُمَرَ بْنِ إِسْحَاقَ بْنِ أَبِي طَلْحَةَ، عَنْ أُمِّهِ، عَنْ أَبِيهَا، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُشَمَّتُ الْعَاطِسُ ثَلاَثًا فَإِنْ زَادَ فَإِنْ شِئْتَ فَشَمِّتْهُ وَإِنْ شِئْتَ فَلاَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ وَإِسْنَادُهُ مَجْهُولٌ ‏.‏\hadithno{2744}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Umar bin Ishaq bin Abi Talhah:from his mother, from her father, who said: "The Messenger of Allah (ﷺ) said: 'Reply three times to the sneezing person. If he (sneezes) more, then if you wish reply and if you do not then do not}}
\hadithdefcmd{tirmidhi}{2745}{حَدَّثَنَا مُحَمَّدُ بْنُ وَزِيرٍ الْوَاسِطِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا عَطَسَ غَطَّى وَجْهَهُ بِيَدِهِ أَوْ بِثَوْبِهِ وَغَضَّ بِهَا صَوْتَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2745}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:that when the Prophet (ﷺ) would sneeze, he would cover his face with his hand or with his garment, and muffle the sound with it}}
\hadithdefcmd{tirmidhi}{2746}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ عَجْلاَنَ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُطَاسُ مِنَ اللَّهِ وَالتَّثَاؤُبُ مِنَ الشَّيْطَانِ فَإِذَا تَثَاءَبَ أَحَدُكُمْ فَلْيَضَعْ يَدَهُ عَلَى فِيهِ وَإِذَا قَالَ آهْ آهْ فَإِنَّ الشَّيْطَانَ يَضْحَكُ مِنْ جَوْفِهِ وَإِنَّ اللَّهَ يُحِبُّ الْعُطَاسَ وَيَكْرَهُ التَّثَاؤُبَ فَإِذَا قَالَ الرَّجُلُ آهْ آهْ إِذَا تَثَاءَبَ فَإِنَّ الشَّيْطَانَ يَضْحَكُ فِي جَوْفِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2746}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "The sneeze is from Allah and the yawn is from Ash-Shaitan. So when one of you yawns let him cover his mouth with his hand. For when he says 'Ah, Ah' Ash-Shaitan laughs from inside his opening." [And indeed Allah loves the sneeze and He dislikes the Yawn, so when a man says Ah, Ah when yawning, indeed Ash-Shaitan laughs from inside his opening]}}
\hadithdefcmd{tirmidhi}{2747}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يُحِبُّ الْعُطَاسَ وَيَكْرَهُ التَّثَاؤُبَ فَإِذَا عَطَسَ أَحَدُكُمْ فَقَالَ الْحَمْدُ لِلَّهِ فَحَقٌّ عَلَى كُلِّ مَنْ سَمِعَهُ أَنْ يَقُولَ يَرْحَمُكَ اللَّهُ وَأَمَّا التَّثَاؤُبُ فَإِذَا تَثَاءَبَ أَحَدُكُمْ فَلْيَرُدَّهُ مَا اسْتَطَاعَ وَلاَ يَقُولَنَّ هَاهْ هَاهْ فَإِنَّمَا ذَلِكَ مِنَ الشَّيْطَانِ يَضْحَكُ مِنْهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ وَهَذَا أَصَحُّ مِنْ حَدِيثِ ابْنِ عَجْلاَنَ ‏.‏ وَابْنُ أَبِي ذِئْبٍ أَحْفَظُ لِحَدِيثِ سَعِيدٍ الْمَقْبُرِيِّ وَأَثْبَتُ مِنْ مُحَمَّدِ بْنِ عَجْلاَنَ ‏.‏ قَالَ سَمِعْتُ أَبَا بَكْرٍ الْعَطَّارَ الْبَصْرِيَّ يَذْكُرُ عَنْ عَلِيِّ بْنِ الْمَدِينِيِّ عَنْ يَحْيَى بْنِ سَعِيدٍ قَالَ قَالَ مُحَمَّدُ بْنُ عَجْلاَنَ أَحَادِيثُ سَعِيدٍ الْمَقْبُرِيِّ رَوَى بَعْضَهَا سَعِيدٌ عَنْ أَبِي هُرَيْرَةَ وَرَوَى بَعْضَهَا سَعِيدٌ عَنْ رَجُلٍ عَنْ أَبِي هُرَيْرَةَ فَاخْتَلَطَتْ عَلَىَّ فَجَعَلْتُهَا عَنْ سَعِيدٍ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{2747}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Indeed Allah loves sneezing and He dislikes the yawn. So when one of you sneezes and says 'Al-Hamdulillah (All praise is due to Allah),' then it is a right due from every one who hears him to say: 'Yarhamukallah (May Allah have mercy upon you)' As for yawning then when one of you yawns let him suppress it as much as possible and not say: "Hah Hah' for that is only from Ash-Shaitan laughing at him}}
\hadithdefcmd{tirmidhi}{2748}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا شَرِيكٌ، عَنْ أَبِي الْيَقْظَانِ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، رَفَعَهُ قَالَ ‏ "‏ الْعُطَاسُ وَالنُّعَاسُ وَالتَّثَاؤُبُ فِي الصَّلاَةِ وَالْحَيْضُ وَالْقَىْءُ وَالرُّعَافُ مِنَ الشَّيْطَانِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ شَرِيكٍ عَنْ أَبِي الْيَقْظَانِ ‏.‏ قَالَ وَسَأَلْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ عَنْ عَدِيِّ بْنِ ثَابِتٍ عَنْ أَبِيهِ عَنْ جَدِّهِ قُلْتُ لَهُ مَا اسْمُ جَدِّ عَدِيٍّ قَالَ لاَ أَدْرِي ‏.‏ وَذُكِرَ عَنْ يَحْيَى بْنِ مَعِينٍ قَالَ اسْمُهُ دِينَارٌ ‏.‏\hadithno{2748}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Yaqzan:from 'Adi - and he is Ibn Thabit - from his father, from his grandfather - [from the Prophet (ﷺ)]: "Sneezing, dozing and yawning during Salat, and menstruation, regurgitation and nosebleeds are from Ash-Shaitan}}
\hadithdefcmd{tirmidhi}{2749}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُقِمْ أَحَدُكُمْ أَخَاهُ مِنْ مَجْلِسِهِ ثُمَّ يَجْلِسُ فِيهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2749}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar:that the Messenger of Allah (ﷺ) said: "Let one of you not have his brother stand from his seat then sit in it}}
\hadithdefcmd{tirmidhi}{2750}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُقِمْ أَحَدُكُمْ أَخَاهُ مِنْ مَجْلِسِهِ ثُمَّ يَجْلِسُ فِيهِ ‏"‏ ‏.‏ قَالَ وَكَانَ الرَّجُلُ يَقُومُ لاِبْنِ عُمَرَ فَلاَ يَجْلِسُ فِيهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2750}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Ibn 'Umar:that the Messenger of Allah (ﷺ) said: "Let one of you not have his brother stand from his seat then sit in it}}
\hadithdefcmd{tirmidhi}{2751}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ الْوَاسِطِيُّ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ عَمِّهِ، وَاسِعِ بْنِ حَبَّانَ، عَنْ وَهْبِ بْنِ حُذَيْفَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الرَّجُلُ أَحَقُّ بِمَجْلِسِهِ وَإِنْ خَرَجَ لِحَاجَتِهِ ثُمَّ عَادَ فَهُوَ أَحَقُّ بِمَجْلِسِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَكْرَةَ وَأَبِي سَعِيدٍ وَأَبِي هُرَيْرَةَ ‏.‏\hadithno{2751}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Wahb bin Hudaifah:that the Messenger of Allah (ﷺ) said: "A man has more right to his seat. If he leaves for some need of his, then he returns, then he has more right to his seat}}
\hadithdefcmd{tirmidhi}{2752}{حَدَّثَنَا سُوَيْدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا أُسَامَةُ بْنُ زَيْدٍ، حَدَّثَنِي عَمْرُو بْنُ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لِلرَّجُلِ أَنْ يُفَرِّقَ بَيْنَ اثْنَيْنِ إِلاَّ بِإِذْنِهِمَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ عَامِرٌ الأَحْوَلُ عَنْ عَمْرِو بْنِ شُعَيْبٍ أَيْضًا ‏.‏\hadithno{2752}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Abdullah bin 'Amr:that the Messenger of Allah (ﷺ) said: "It is not lawful for a man to separate two people except with their permission}}
\hadithdefcmd{tirmidhi}{2753}{حَدَّثَنَا سُوَيْدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي مِجْلَزٍ، أَنَّ رَجُلاً، قَعَدَ وَسْطَ حَلْقَةٍ فَقَالَ حُذَيْفَةُ مَلْعُونٌ عَلَى لِسَانِ مُحَمَّدٍ أَوْ لَعَنَ اللَّهُ عَلَى لِسَانِ مُحَمَّدٍ صلى الله عليه وسلم - مَنْ قَعَدَ وَسْطَ الْحَلْقَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَأَبُو مِجْلَزٍ اسْمُهُ لاَحِقُ بْنُ حُمَيْدٍ ‏.‏\hadithno{2753}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Miljaz:that a man sat in the middle of a circle so Hudhaifah said: "Cursed upon the tongue of Muhammad - or - Cursed, by Allah upon the tongue of Muhammad (ﷺ), is he who sits in the middle of a the circle}}
\hadithdefcmd{tirmidhi}{2754}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا عَفَّانُ، أَخْبَرَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ لَمْ يَكُنْ شَخْصٌ أَحَبَّ إِلَيْهِمْ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ وَكَانُوا إِذَا رَأَوْهُ لَمْ يَقُومُوا لِمَا يَعْلَمُونَ مِنْ كَرَاهِيَتِهِ لِذَلِكَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2754}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas:"There was no person more beloved to them than the Messenger of Allah (ﷺ)." [He said:] "And they would not stand when they saw him because they knew that he disliked that}}
\hadithdefcmd{tirmidhi}{2755}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ حَبِيبِ بْنِ الشَّهِيدِ، عَنْ أَبِي مِجْلَزٍ، قَالَ خَرَجَ مُعَاوِيَةُ فَقَامَ عَبْدُ اللَّهِ بْنُ الزُّبَيْرِ وَابْنُ صَفْوَانَ حِينَ رَأَوْهُ ‏.‏ فَقَالَ اجْلِسَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ سَرَّهُ أَنْ يَتَمَثَّلَ لَهُ الرِّجَالُ قِيَامًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي أُمَامَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ حَبِيبِ بْنِ الشَّهِيدِ، عَنْ أَبِي مِجْلَزٍ، عَنْ مُعَاوِيَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{2755}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Miljaz:that Mu'awiyah came out and 'Abdullah bin Az-Zubair and Ibn Safwan stood for him when they saw him, so he said: "Sit, I heard the Messenger of Allah (ﷺ) saying: 'Whoever wishes that he be received by men standing then, let him take his seat in the Fire}}
\hadithdefcmd{tirmidhi}{2756}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ الْخَلاَّلُ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَمْسٌ مِنَ الْفِطْرَةِ الاِسْتِحْدَادُ وَالْخِتَانُ وَقَصُّ الشَّارِبِ وَنَتْفُ الإِبْطِ وَتَقْلِيمُ الأَظْفَارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2756}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Five are from the Fitrah: Cutting the pubic hair, circumcision, paring the mustache, plucking the under arm hair and trimming the fingernails}}
\hadithdefcmd{tirmidhi}{2757}{حَدَّثَنَا قُتَيْبَةُ، وَهَنَّادٌ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ مُصْعَبِ بْنِ شَيْبَةَ، عَنْ طَلْقِ بْنِ حَبِيبٍ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ عَشْرٌ مِنَ الْفِطْرَةِ قَصُّ الشَّارِبِ وَإِعْفَاءُ اللِّحْيَةِ وَالسِّوَاكُ وَالاِسْتِنْشَاقُ وَقَصُّ الأَظْفَارِ وَغَسْلُ الْبَرَاجِمِ وَنَتْفُ الإِبْطِ وَحَلْقُ الْعَانَةِ وَانْتِقَاصُ الْمَاءِ ‏"‏ ‏.‏ قَالَ زَكَرِيَّا قَالَ مُصْعَبٌ وَنَسِيتُ الْعَاشِرَةَ إِلاَّ أَنْ تَكُونَ الْمَضْمَضَةَ ‏.‏ قَالَ أَبُو عُبَيْدٍ انْتِقَاصُ الْمَاءِ الاِسْتِنْجَاءُ بِالْمَاءِ ‏.‏ وَفِي الْبَابِ عَنْ عَمَّارِ بْنِ يَاسِرٍ وَابْنِ عُمَرَ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2757}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated 'Aishah:that the Prophet (ﷺ) said: "Ten are from the Fitrah: Paring the mustache, leaving the beard to grow, Siwak, cleaning the nose with water, paring the fingernails, washing the knuckles, plucking the underarm hair, shaving the pubic hairs, and Intiqas with water}}
\hadithdefcmd{tirmidhi}{2758}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا صَدَقَةُ بْنُ مُوسَى أَبُو مُحَمَّدٍ، صَاحِبُ الدَّقِيقِ حَدَّثَنَا أَبُو عِمْرَانَ الْجَوْنِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ وَقَّتَ لَهُمْ فِي كُلِّ أَرْبَعِينَ لَيْلَةً تَقْلِيمَ الأَظْفَارِ وَأَخْذَ الشَّارِبِ وَحَلْقَ الْعَانَةِ ‏.‏\hadithno{2758}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas:from the Prophet (ﷺ), that he (ﷺ) fixed the time as every forty nights for them to trimming the fingernails, taking from the mustache, and shaving the pubic hairs}}
\hadithdefcmd{tirmidhi}{2759}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ وَقَّتَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي قَصِّ الشَّارِبِ وَتَقْلِيمِ الأَظْفَارِ وَحَلْقِ الْعَانَةِ وَنَتْفِ الإِبْطِ أَنْ لاَ نَتْرُكَ أَكْثَرَ مِنْ أَرْبَعِينَ يَوْمًا ‏.‏ قَالَ هَذَا أَصَحُّ مِنْ حَدِيثِ الأَوَّلِ ‏.‏ وَصَدَقَةُ بْنُ مُوسَى لَيْسَ عِنْدَهُمْ بِالْحَافِظِ ‏.‏\hadithno{2759}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Anas bin Malik:"[The Messenger of Allah (ﷺ)] fixed the time for us paring the mustache, trimming the fingernails, shaving the pubic hairs and plucking the underarm hairs - that we not leave it for more than forty days}}
\hadithdefcmd{tirmidhi}{2760}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ الْوَلِيدِ الْكِنْدِيُّ الْكُوفِيُّ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ إِسْرَائِيلَ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُصُّ أَوْ يَأْخُذُ مِنْ شَارِبِهِ وَكَانَ إِبْرَاهِيمُ خَلِيلُ الرَّحْمَنِ يَفْعَلُهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2760}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:"The Prophet (ﷺ) would pare, or take from his mustache, and Ibrahim Khalilur-Rahman would do it (as well)}}
\hadithdefcmd{tirmidhi}{2761}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنْ يُوسُفَ بْنِ صُهَيْبٍ، عَنْ حَبِيبِ بْنِ يَسَارٍ، عَنْ زَيْدِ بْنِ أَرْقَمَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَمْ يَأْخُذْ مِنْ شَارِبِهِ فَلَيْسَ مِنَّا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ يُوسُفَ بْنِ صُهَيْبٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{2761}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Zaid bin Arqam:that the Messenger of Allah (ﷺ) said: "Whoever does not take from his mustache, then he is not from us}}
\hadithdefcmd{tirmidhi}{2762}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عُمَرُ بْنُ هَارُونَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَأْخُذُ مِنْ لِحْيَتِهِ مِنْ عَرْضِهَا وَطُولِهَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَسَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يَقُولُ عُمَرُ بْنُ هَارُونَ مُقَارِبُ الْحَدِيثِ لاَ أَعْرِفُ لَهُ حَدِيثًا لَيْسَ إِسْنَادُهُ أَصْلاً أَوْ قَالَ يَنْفَرِدُ بِهِ إِلاَّ هَذَا الْحَدِيثَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَأْخُذُ مِنْ لِحْيَتِهِ مِنْ عَرْضِهَا وَطُولِهَا ‏.‏ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عُمَرَ بْنِ هَارُونَ وَرَأَيْتُهُ حَسَنَ الرَّأْىِ فِي عُمَرَ بْنِ هَارُونَ ‏.‏ قَالَ أَبُو عِيسَى وَسَمِعْتُ قُتَيْبَةَ يَقُولُ عُمَرُ بْنُ هَارُونَ كَانَ صَاحِبَ حَدِيثٍ وَكَانَ يَقُولُ الإِيمَانُ قَوْلٌ وَعَمَلٌ ‏.‏ قَالَ سَمِعْتُ قُتَيْبَةَ، حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، عَنْ رَجُلٍ، عَنْ ثَوْرِ بْنِ يَزِيدَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَصَبَ الْمَنْجَنِيقَ عَلَى أَهْلِ الطَّائِفِ ‏.‏ قَالَ قُتَيْبَةُ قُلْتُ لِوَكِيعٍ مَنْ هَذَا قَالَ صَاحِبُكُمْ عُمَرُ بْنُ هَارُونَ ‏.‏\hadithno{2762}\hadithgrade{Ahmad Muhammad Shakir: Mawdu; Al-Albani: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Amr bin Shu'aib:from his father, from his grandfather that he Prophet (ﷺ) would take from his beard; from its breadth and its length}}
\hadithdefcmd{tirmidhi}{2763}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَحْفُوا الشَّوَارِبَ وَأَعْفُوا اللِّحَى ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2763}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Ibn 'Umar:that the Messenger of Allah (ﷺ) said: "Trim the mustache and leave the beard to grow}}
\hadithdefcmd{tirmidhi}{2764}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي بَكْرِ بْنِ نَافِعٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَنَا بِإِحْفَاءِ الشَّوَارِبِ وَإِعْفَاءِ اللِّحَى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو بَكْرِ بْنُ نَافِعٍ هُوَ مَوْلَى ابْنِ عُمَرَ ثِقَةٌ وَعُمَرُ بْنُ نَافِعٍ ثِقَةٌ وَعَبْدُ اللَّهِ بْنُ نَافِعٍ مَوْلَى ابْنِ عُمَرَ يُضَعَّفُ ‏.‏\hadithno{2764}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Ibn 'Umar:that the Messenger of Allah (ﷺ) ordered trimming the mustache and leaving the beard to grow}}
\hadithdefcmd{tirmidhi}{2765}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عن عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم مُسْتَلْقِيًا فِي الْمَسْجِدِ وَاضِعًا إِحْدَى رِجْلَيْهِ عَلَى الأُخْرَى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَعَمُّ عَبَّادِ بْنِ تَمِيمٍ هُوَ عَبْدُ اللَّهِ بْنُ زَيْدِ بْنِ عَاصِمٍ الْمَازِنِيُّ ‏.‏\hadithno{2765}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abbad bin Tamim:from his paternal uncle, that he saw the Prophet (ﷺ) reclining in the Masjid, and placing one of his feet atop another}}
\hadithdefcmd{tirmidhi}{2766}{حَدَّثَنَا عُبَيْدُ بْنُ أَسْبَاطِ بْنِ مُحَمَّدٍ الْقُرَشِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا سُلَيْمَانُ التَّيْمِيُّ، عَنْ خِدَاشٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا اسْتَلْقَى أَحَدُكُمْ عَلَى ظَهْرِهِ فَلاَ يَضَعْ إِحْدَى رِجْلَيْهِ عَلَى الأُخْرَى ‏"‏ ‏.‏ هَذَا حَدِيثٌ رَوَاهُ غَيْرُ وَاحِدٍ عَنْ سُلَيْمَانَ التَّيْمِيِّ ‏.‏ وَلاَ يُعْرَفُ خِدَاشٌ هَذَا مَنْ هُوَ وَقَدْ رَوَى لَهُ سُلَيْمَانُ التَّيْمِيُّ غَيْرَ حَدِيثٍ ‏.‏\hadithno{2766}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir:"The Messenger of Allah (ﷺ) prohibited Ishtimal As-Samma, Al-Ihtiba in one garment, and that a man raise one of his feet atop the other while he is reclining on his back}}
\hadithdefcmd{tirmidhi}{2767}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ اشْتِمَالِ الصَّمَّاءِ وَالاِحْتِبَاءِ فِي ثَوْبٍ وَاحِدٍ وَأَنْ يَرْفَعَ الرَّجُلُ إِحْدَى رِجْلَيْهِ عَلَى الأُخْرَى وَهُوَ مُسْتَلْقٍ عَلَى ظَهْرِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2767}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir:"The Messenger of Allah (ﷺ) prohibited Ishtimal As-Samma, Al-Ihtiba in one garment, and that a man raise one of his feet atop the other while he is reclining on his back}}
\hadithdefcmd{tirmidhi}{2768}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، وَعَبْدُ الرَّحِيمِ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً مُضْطَجِعًا عَلَى بَطْنِهِ فَقَالَ ‏ "‏ إِنَّ هَذِهِ ضَجْعَةٌ لاَ يُحِبُّهَا اللَّهُ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ طِهْفَةَ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى يَحْيَى بْنُ أَبِي كَثِيرٍ هَذَا الْحَدِيثَ عَنْ أَبِي سَلَمَةَ عَنْ يَعِيشَ بْنِ طِهْفَةَ عَنْ أَبِيهِ وَيُقَالُ طِخْفَةُ وَالصَّحِيحُ طِهْفَةُ ‏.‏ وَقَالَ بَعْضُ الْحُفَّاظِ الصَّحِيحُ طِخْفَةُ وَيُقَالُ طِغْفَةُ ‏.‏ يَعِيشُ هُوَ مِنَ الصَّحَابَةِ ‏.‏\hadithno{2768}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) saw a man laying on his stomach so he said: "Indeed such laying is not loved by Allah}}
\hadithdefcmd{tirmidhi}{2769}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا بَهْزُ بْنُ حَكِيمٍ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ عَوْرَاتُنَا مَا نَأْتِي مِنْهَا وَمَا نَذَرُ قَالَ ‏"‏ احْفَظْ عَوْرَتَكَ إِلاَّ مِنْ زَوْجَتِكَ أَوْ مِمَّا مَلَكَتْ يَمِينُكَ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ يَكُونُ مَعَ الرَّجُلِ قَالَ ‏"‏ إِنِ اسْتَطَعْتَ أَنْ لاَ يَرَاهَا أَحَدٌ فَافْعَلْ ‏"‏ ‏.‏ قُلْتُ وَالرَّجُلُ يَكُونُ خَالِيًا ‏.‏ قَالَ ‏"‏ فَاللَّهُ أَحَقُّ أَنْ يُسْتَحْيَا مِنْهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَجَدُّ بَهْزٍ اسْمُهُ مُعَاوِيَةُ بْنُ حَيْدَةَ الْقُشَيْرِيُّ وَقَدْ رَوَى الْجُرَيْرِيُّ عَنْ حَكِيمِ بْنِ مُعَاوِيَةَ وَهُوَ وَالِدُ بَهْزٍ ‏.‏\hadithno{2769}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Bahz bin Hakim:"My father narrated to me from my grandfather, who said: 'I said: "O Messenger of Allah! Regarding our 'Awrah, what of it must we cover and what of it may we leave?" He said: "Protect your 'Awrah except from your wife or what your right hand possesses."' He said: "What about a man with another man?" He said: "If you are able to not let anyone see it, then do so." I said: "What about a man when he is alone?" He said: "Allah is most deserving of being shy from Him}}
\hadithdefcmd{tirmidhi}{2770}{حَدَّثَنَا عَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ الْبَغْدَادِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ الْكُوفِيُّ، أَخْبَرَنَا إِسْرَائِيلُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم مُتَّكِئًا عَلَى وِسَادَةٍ عَلَى يَسَارِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَرَوَى غَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ إِسْرَائِيلَ عَنْ سِمَاكٍ عَنْ جَابِرِ بْنِ سَمُرَةَ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم مُتَّكِئًا عَلَى وِسَادَةٍ ‏.‏ وَلَمْ يَذْكُرْ عَلَى يَسَارِهِ ‏.‏\hadithno{2770}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir bin Samurah:"I saw the Messenger of Allah (ﷺ) reclining upon as pillow, on his left side}}
\hadithdefcmd{tirmidhi}{2771}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم مُتَّكِئًا عَلَى وِسَادَةٍ ‏.‏ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2771}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir bin Samurah:"I saw the Prophet (ﷺ) reclining upon a pillow}}
\hadithdefcmd{tirmidhi}{2772}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِسْمَاعِيلَ بْنِ رَجَاءٍ، عَنْ أَوْسِ بْنِ ضَمْعَجٍ، عَنْ أَبِي مَسْعُودٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُؤَمُّ الرَّجُلُ فِي سُلْطَانِهِ وَلاَ يُجْلَسُ عَلَى تَكْرِمَتِهِ فِي بَيْتِهِ إِلاَّ بِإِذْنِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2772}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Mas'ud:that the Messenger of Allah (ﷺ) said: "A man is not lead in his dominion, and his seat of honor in his house is not sat in without his permission}}
\hadithdefcmd{tirmidhi}{2773}{حَدَّثَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا عَلِيُّ بْنُ الْحُسَيْنِ بْنِ وَاقِدٍ، حَدَّثَنِي أَبِي، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، قَالَ سَمِعْتُ أَبِي بُرَيْدَةَ، يَقُولُ بَيْنَمَا النَّبِيُّ صلى الله عليه وسلم يَمْشِي إِذْ جَاءَهُ رَجُلٌ وَمَعَهُ حِمَارٌ فَقَالَ يَا رَسُولَ اللَّهِ ارْكَبْ ‏.‏ وَتَأَخَّرَ الرَّجُلُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْتَ أَحَقُّ بِصَدْرِ دَابَّتِكَ إِلاَّ أَنْ تَجْعَلَهُ لِي ‏"‏ ‏.‏ قَالَ قَدْ جَعَلْتُهُ لَكَ ‏.‏ قَالَ فَرَكِبَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَفِي الْبَابِ عَنْ قَيْسِ بْنِ سَعْدِ بْنِ عُبَادَةَ ‏.‏\hadithno{2773}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Abdullah bin Buraidah:"I heard my father Buraidah saying: 'I was walking with the Prophet (ﷺ) when a man came to him with a donkey, so he said: "O Messenger of Allah! Ride" and the man moved toward the back. The Messenger of Allah (ﷺ) said: "No, you have more right to the front of your beast, unless you allot it for me." He said: "I have allotted it for you.'" He said: 'So he rode}}
\hadithdefcmd{tirmidhi}{2774}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ لَكُمْ أَنْمَاطٌ ‏"‏ ‏.‏ قُلْتُ وَأَنَّى تَكُونُ لَنَا أَنْمَاطٌ قَالَ ‏"‏ أَمَا إِنَّهَا سَتَكُونُ لَكُمْ أَنْمَاطٌ ‏"‏ ‏.‏ قَالَ فَأَنَا أَقُولُ لاِمْرَأَتِي أَخِّرِي عَنِّي أَنْمَاطَكِ فَتَقُولُ أَلَمْ يَقُلِ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّهَا سَتَكُونُ لَكُمْ أَنْمَاطٌ ‏"‏ ‏.‏ قَالَ فَأَدَعُهَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2774}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Jabir:that the Messenger of Allah (ﷺ) said: "Do you have Anmat?" I said: "Where would we get Anmat from?" He said: "Soon you will have Anmat" He said: "I would say to my wife: 'Remove your Anmat from my sight.' But she would say: 'Did not the Messenger of Allah (ﷺ) say: "Indeed you shall soon have Anmat?" He said: "So I left it}}
\hadithdefcmd{tirmidhi}{2775}{حَدَّثَنَا عَبَّاسٌ الْعَنْبَرِيُّ بْنُ عَبْدِ الْعَظِيمِ، حَدَّثَنَا النَّضْرُ بْنُ مُحَمَّدٍ، هُوَ الْجُرَشِيُّ الْيَمَامِيُّ حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، عَنْ إِيَاسِ بْنِ سَلَمَةَ، عَنْ أَبِيهِ، قَالَ لَقَدْ قُدْتُ نَبِيَّ اللَّهِ صلى الله عليه وسلم وَالْحَسَنَ وَالْحُسَيْنَ عَلَى بَغْلَتِهِ الشَّهْبَاءِ حَتَّى أَدْخَلْتُهُ حُجْرَةَ النَّبِيِّ صلى الله عليه وسلم هَذَا قُدَّامُهُ وَهَذَا خَلْفُهُ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَعَبْدِ اللَّهِ بْنِ جَعْفَرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2775}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Iyas bin Salamah:from his father who said: "I guided Allah's Prophet (ﷺ) and Al-Hasan and Al-Husain, on his gray mule until I brought him to the apartment of the Prophet (ﷺ), this one was in front of him, and this one behind him}}
\hadithdefcmd{tirmidhi}{2776}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا يُونُسُ بْنُ عُبَيْدٍ، عَنْ عَمْرِو بْنِ سَعِيدٍ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ نَظْرَةِ الْفَجْأَةِ فَأَمَرَنِي أَنْ أَصْرِفَ بَصَرِي ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو زُرْعَةَ بْنُ عَمْرٍو اسْمُهُ هَرِمٌ ‏.‏\hadithno{2776}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir bin 'Abdullah:"I asked the Messenger Of Allah (ﷺ) about the unintentional glance, so he ordered me that I divert my sight}}
\hadithdefcmd{tirmidhi}{2777}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا شَرِيكٌ، عَنْ أَبِي رَبِيعَةَ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، رَفَعَهُ قَالَ ‏ "‏ يَا عَلِيُّ لاَ تُتْبِعِ النَّظْرَةَ النَّظْرَةَ فَإِنَّ لَكَ الأُولَى وَلَيْسَتْ لَكَ الآخِرَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ شَرِيكٍ ‏.‏\hadithno{2777}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn Buraidah:from his father (from the Prophet (ﷺ)) who said: "O 'Ali! Do not follow a look with a look, the first is for you, but the next is not for you}}
\hadithdefcmd{tirmidhi}{2778}{حَدَّثَنَا سُوَيْدٌ، حَدَّثَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ نَبْهَانَ، مَوْلَى أُمِّ سَلَمَةَ أَنَّهُ حَدَّثَهُ أَنَّ أُمَّ سَلَمَةَ حَدَّثَتْهُ أَنَّهَا، كَانَتْ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَمَيْمُونَةُ قَالَتْ فَبَيْنَا نَحْنُ عِنْدَهُ أَقْبَلَ ابْنُ أُمِّ مَكْتُومٍ فَدَخَلَ عَلَيْهِ وَذَلِكَ بَعْدَ مَا أُمِرْنَا بِالْحِجَابِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ احْتَجِبَا مِنْهُ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ أَلَيْسَ هُوَ أَعْمَى لاَ يُبْصِرُنَا وَلاَ يَعْرِفُنَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَفَعَمْيَاوَانِ أَنْتُمَا أَلَسْتُمَا تُبْصِرَانِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2778}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Nabhan the freed slave of Umm Salamah:to Ibn Shihab, that Umm Salamah narrated to him, that she and Maimunah were with the Messenger of Allah (ﷺ), she said: "So when we were with him, Ibn Umm Maktum came, and he entered upon him, and that was after veiling had been ordered for us. So the Messenger of Allah (ﷺ) said: 'Veil yourselves from him.' So I said: 'O Messenger of Allah! Is he not blind such that he can not see us or recognize us?' So the Messenger of Allah (ﷺ) said: 'Are you two blind such that you can not see him?}}
\hadithdefcmd{tirmidhi}{2779}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ ذَكْوَانَ، عَنْ مَوْلَى، عَمْرِو بْنِ الْعَاصِي أَنَّ عَمْرَو بْنَ الْعَاصِي، أَرْسَلَهُ إِلَى عَلِيٍّ يَسْتَأْذِنُهُ عَلَى أَسْمَاءَ بِنْتِ عُمَيْسٍ فَأَذِنَ لَهُ حَتَّى إِذَا فَرَغَ مِنْ حَاجَتِهِ سَأَلَ الْمَوْلَى عَمْرَو بْنَ الْعَاصِي عَنْ ذَلِكَ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَانَا أَنْ نَدْخُلَ عَلَى النِّسَاءِ بِغَيْرِ إِذْنِ أَزْوَاجِهِنَّ ‏.‏ وَفِي الْبَابِ عَنْ عُقْبَةَ بْنِ عَامِرٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2779}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Dhakwan:from the freed slave of 'Amr bin Al-'As that 'Amr bin Al-'As sent him to 'Ali seeking his permission to enter upon Asma bint Umais, so he permitted him. When he was finished from what he needed, the freed slave of 'Amr bin Al-'As asked about that, so he said: "Indeed the Prophet (ﷺ) prohibited us - or - prohibited that we enter upon women, without the permission of their husbands}}
\hadithdefcmd{tirmidhi}{2780}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، عَنْ أَبِي عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، وَسَعِيدِ بْنِ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا تَرَكْتُ بَعْدِي فِي النَّاسِ فِتْنَةً أَضَرَّ عَلَى الرِّجَالِ مِنَ النِّسَاءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى هَذَا الْحَدِيثَ غَيْرُ وَاحِدٍ مِنَ الثِّقَاتِ عَنْ سُلَيْمَانَ التَّيْمِيِّ عَنْ أَبِي عُثْمَانَ عَنْ أُسَامَةَ بْنِ زَيْدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَذْكُرُوا فِيهِ عَنْ سَعِيدِ بْنِ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ وَلاَ نَعْلَمُ أَحَدًا قَالَ عَنْ أُسَامَةَ بْنِ زَيْدٍ وَسَعِيدِ بْنِ زَيْدٍ غَيْرَ الْمُعْتَمِرِ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ ‏.‏\hadithno{2780}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Usamah bin Zaid, and Sa'eed bin Zaid bin 'Amr bin Nufail:that the Prophet (ﷺ) said: "I have not left among the people after me, a Fitnah more harmful upon men than women}}
\hadithdefcmd{tirmidhi}{2780p2}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{2780.2}\hadithtrans{Another chain with a similar narration}}
\hadithdefcmd{tirmidhi}{2781}{حَدَّثَنَا سُوَيْدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، أَخْبَرَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ مُعَاوِيَةَ، بِالْمَدِينَةِ يَخْطُبُ يَقُولُ أَيْنَ عُلَمَاؤُكُمْ يَا أَهْلَ الْمَدِينَةِ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْ هَذِهِ الْقُصَّةِ وَيَقُولُ ‏ "‏ إِنَّمَا هَلَكَتْ بَنُو إِسْرَائِيلَ حِينَ اتَّخَذَهَا نِسَاؤُهُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ مُعَاوِيَةَ ‏.‏\hadithno{2781}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Humaid bin 'Abdur-Rahman:that he heard Mu'awiyah giving a Khutbah in Al-Madinah, and saying: "Where are your scholars, O people of Al-Madinah? [Indeed] I heard the Messenger of Allah (ﷺ) forbidding from these locks (of hair), and saying: 'The Children of Isra'il were only ruined when their women used them}}
\hadithdefcmd{tirmidhi}{2782}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَعَنَ الْوَاشِمَاتِ وَالْمُسْتَوْشِمَاتِ وَالْمُتَنَمِّصَاتِ مُبْتَغِيَاتٍ لِلْحُسْنِ مُغَيِّرَاتٍ خَلْقَ اللَّهِ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ شُعْبَةُ وَغَيْرُ وَاحِدٍ مِنَ الأَئِمَّةِ عَنْ مَنْصُورٍ ‏.‏\hadithno{2782}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah:that the Prophet (ﷺ) cursed the women who practice tattooing and those who seek to be tattooed, the women who remove hair from their faces seeking beautification by changing the creation of Allah}}
\hadithdefcmd{tirmidhi}{2783}{حَدَّثَنَا سُوَيْدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَعَنَ اللَّهُ الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ وَالْوَاشِمَةَ وَالْمُسْتَوْشِمَةَ ‏"‏ ‏.‏ قَالَ نَافِعٌ الْوَشْمُ فِي اللِّثَةِ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ عَائِشَةَ وَمَعْقِلِ بْنِ يَسَارٍ وَأَسْمَاءَ بِنْتِ أَبِي بَكْرٍ وَابْنِ عَبَّاسٍ ‏.‏\hadithno{2783}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar:that the Prophet (ﷺ) said: "Allah's curse is upon the woman who lengthens hair and the women who seeks to have her hair lengthened, and the woman who tattoos and the woman who seeks to have her herself tattooed}}
\hadithdefcmd{tirmidhi}{2783p2}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَلَمْ يَذْكُرْ فِيهِ يَحْيَى قَوْلَ نَافِعٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2783.2}\hadithtrans{(Another chain) with a similar narration}}
\hadithdefcmd{tirmidhi}{2784}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا شُعْبَةُ، وَهَمَّامٌ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمُتَشَبِّهَاتِ بِالرِّجَالِ مِنَ النِّسَاءِ وَالْمُتَشَبِّهِينَ بِالنِّسَاءِ مِنَ الرِّجَالِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2784}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Ibn 'Abbas:"The Messenger of Allah (ﷺ) cursed the women who imitate men and the men who imitate women}}
\hadithdefcmd{tirmidhi}{2785}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، وَأَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمُخَنَّثِينَ مِنَ الرِّجَالِ وَالْمُتَرَجِّلاَتِ مِنَ النِّسَاءِ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ عَائِشَةَ ‏.‏\hadithno{2785}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Abbas:"The Messenger of Allah (ﷺ) cursed those men who behave effeminately and those women whose behavior is masculine}}
\hadithdefcmd{tirmidhi}{2786}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ ثَابِتِ بْنِ عِمَارَةَ الْحَنَفِيِّ، عَنْ غُنَيْمِ بْنِ قَيْسٍ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ عَيْنٍ زَانِيَةٌ وَالْمَرْأَةُ إِذَا اسْتَعْطَرَتْ فَمَرَّتْ بِالْمَجْلِسِ فَهِيَ كَذَا وَكَذَا يَعْنِي زَانِيَةً ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2786}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Musa:that the Prophet (ﷺ) said: "Every eye commits adultery, and when the woman uses perfume and she passes by a gathering, then she is like this and that.'" Meaning an adulteress}}
\hadithdefcmd{tirmidhi}{2787}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عَنْ سُفْيَانَ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ رَجُلٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ طِيبُ الرِّجَالِ مَا ظَهَرَ رِيحُهُ وَخَفِيَ لَوْنُهُ وَطِيبُ النِّسَاءِ مَا ظَهَرَ لَوْنُهُ وَخَفِيَ رِيحُهُ ‏"‏ ‏.‏\hadithno{2787}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Fragrance for men is that which its scent is apparent and its color is hidden, and fragrance for women is that which its color is visible and its scent is hidden." (Meaning when leaving the home as indicated by the previous chapter. As far as in the presence of the husband, then the woman may wear fragrant perfume)}}
\hadithdefcmd{tirmidhi}{2787p2}{\hadithno{2787.2}\hadithtrans{Another chain of narration similar in meaning}}
\hadithdefcmd{tirmidhi}{2788}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ لِي النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ خَيْرَ طِيبِ الرَّجُلِ مَا ظَهَرَ رِيحُهُ وَخَفِيَ لَوْنُهُ وَخَيْرَ طِيبِ النِّسَاءِ مَا ظَهَرَ لَوْنُهُ وَخَفِيَ رِيحُهُ ‏"‏ ‏.‏ وَنَهَى عَنْ مِيثَرَةِ الأُرْجُوَانِ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2788}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Imran bin Husain:"The Prophet (ﷺ) said [to me]: 'Indeed the best fragrance for men is what's scent is apparent and its color is hidden, and the best fragrance for women is what's color is visible and its scent is hidden.' And he prohibited Mitharatil-Urjawan (Mitharah was some type of saddle cloth. Some of the people of knowledge say it was a certain kind of cloth made of silk, and it preceded earlier under no. 1760. They disagree over Al-Urjawan, and perhaps it means whatever is red, meaning the Red Mitahrah, see Tuhfat Al-Ahwadhi)}}
\hadithdefcmd{tirmidhi}{2789}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا عَزْرَةُ بْنُ ثَابِتٍ، عَنْ ثُمَامَةَ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ أَنَسٌ لاَ يَرُدُّ الطِّيبَ ‏.‏ وَقَالَ أَنَسٌ إِنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ لاَ يَرُدُّ الطِّيبَ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2789}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Thumamah bin 'Abdullah:"Anas would not refuse perfume, and Anas said: 'Indeed the Prophet (ﷺ) would not refuse perfume}}
\hadithdefcmd{tirmidhi}{2790}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُسْلِمٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثٌ لاَ تُرَدُّ الْوَسَائِدُ وَالدُّهْنُ وَاللَّبَنُ ‏"‏ ‏.‏ الدُّهْنُ يَعْنِي بِهِ الطِّيبَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ وَعَبْدُ اللَّهِ هُوَ ابْنُ مُسْلِمِ بْنِ جُنْدَبٍ وَهُوَ مَدَنِيٌّ ‏.‏\hadithno{2790}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Umar:that the Messenger of Allah (ﷺ) said: "There are three that are not refused: Cushions, oils [Duhn (fragrance)], and milk}}
\hadithdefcmd{tirmidhi}{2791}{حَدَّثَنَا مُحَمَّدُ بْنُ خَلِيفَةَ أَبُو عَبْدِ اللَّهِ، - بَصْرِيٌّ - وَعَمْرُو بْنُ عَلِيٍّ قَالاَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ حَجَّاجٍ الصَّوَّافِ، عَنْ حَنَانٍ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أُعْطِيَ أَحَدُكُمُ الرَّيْحَانَ فَلاَ يَرُدَّهُ فَإِنَّهُ خَرَجَ مِنَ الْجَنَّةِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَلاَ نَعْرِفُ حَنَانًا إِلاَّ فِي هَذَا الْحَدِيثِ وَأَبُو عُثْمَانَ النَّهْدِيُّ اسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ مُلٍّ وَقَدْ أَدْرَكَ زَمَنَ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَرَهُ وَلَمْ يَسْمَعْ مِنْهُ ‏.‏\hadithno{2791}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu 'Uthman An-Nahdi:"The Messenger of Allah (ﷺ) said: 'When one of you is given some fragrance then do not refuse it, for indeed it comes from Paradise}}
\hadithdefcmd{tirmidhi}{2792}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقِ بْنِ سَلَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُبَاشِرُ الْمَرْأَةُ الْمَرْأَةَ حَتَّى تَصِفَهَا لِزَوْجِهَا كَأَنَّمَا يَنْظُرُ إِلَيْهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2792}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated 'Abdullah:that the Messenger of Allah (ﷺ) said: "A woman is not to touch a woman such that she can describe her to her husband as if he is looking at her}}
\hadithdefcmd{tirmidhi}{2793}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، أَخْبَرَنِي الضَّحَّاكُ بْنُ عُثْمَانَ، أَخْبَرَنِي زَيْدُ بْنُ أَسْلَمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَنْظُرُ الرَّجُلُ إِلَى عَوْرَةِ الرَّجُلِ وَلاَ تَنْظُرُ الْمَرْأَةُ إِلَى عَوْرَةِ الْمَرْأَةِ وَلاَ يُفْضِي الرَّجُلُ إِلَى الرَّجُلِ فِي الثَّوْبِ الْوَاحِدِ وَلاَ تُفْضِي الْمَرْأَةُ إِلَى الْمَرْأَةِ فِي الثَّوْبِ الْوَاحِدِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2793}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated 'Abdur-Rahman bin Abi Sa'eed [Al-Khudri] from his father who said:"The Messenger of Allah (ﷺ) said: 'A man is not to look at the 'Awrah of a man, and a woman is not to look at the 'Awrah of a woman. A man is not to be alone with a man under one garment, and a woman is not to be alone with a woman under one garment}}
\hadithdefcmd{tirmidhi}{2794}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، وَيَزِيدُ بْنُ هَارُونَ، قَالاَ حَدَّثَنَا بَهْزُ بْنُ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قُلْتُ يَا نَبِيَّ اللَّهِ عَوْرَاتُنَا مَا نَأْتِي مِنْهَا وَمَا نَذَرُ قَالَ ‏"‏ احْفَظْ عَوْرَتَكَ إِلاَّ مِنْ زَوْجَتِكَ أَوْ مَا مَلَكَتْ يَمِينُكَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِذَا كَانَ الْقَوْمُ بَعْضُهُمْ فِي بَعْضٍ قَالَ ‏"‏ إِنِ اسْتَطَعْتَ أَنْ لاَ يَرَاهَا أَحَدٌ فَلاَ يَرَيَنَّهَا ‏"‏ ‏.‏ قَالَ قُلْتُ يَا نَبِيَّ اللَّهِ إِذَا كَانَ أَحَدُنَا خَالِيًا قَالَ ‏"‏ فَاللَّهُ أَحَقُّ أَنْ يَسْتَحْيِيَ مِنْهُ النَّاسُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2794}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Bahz bin Hakim:from his father, from his grandfather, who said: "I said: 'O Prophet of Allah! Regarding our 'Awrah, what of it must we cover and what of it may we leave?' He said: 'Protect your 'Awrah except from your wife or what your right hand possesses.' He said: "I said: 'O Messenger of Allah! What about when some people are with others?' He said: 'If you are able to not let anyone see it then do not let them see it.'" He said: "I said: 'O Prophet of Allah! What about when one of us is alone?' He said: 'Allah is more deserving of being shy from Him than the people}}
\hadithdefcmd{tirmidhi}{2796}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى الْكُوفِيُّ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي يَحْيَى، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْفَخِذُ عَوْرَةٌ ‏"‏ ‏.‏\hadithno{2796}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Abdullah bin Jardah Al-Aslami:from his father, from the Prophet (ﷺ) who said: "The thigh is 'Awrah}}
\hadithdefcmd{tirmidhi}{2797}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنِ الْحَسَنِ بْنِ صَالِحٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ عَبْدِ اللَّهِ بْنِ جَرْهَدٍ الأَسْلَمِيِّ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْفَخِذُ عَوْرَةٌ ‏"‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَمُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ جَحْشٍ وَلِعَبْدِ اللَّهِ بْنِ جَحْشٍ صُحْبَةٌ وَلاِبْنِهِ مُحَمَّدٍ صُحْبَةٌ ‏.‏\hadithno{2797}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn 'Abbas:that the Prophet (ﷺ) said: "The thigh is 'Awrah}}
\hadithdefcmd{tirmidhi}{2798}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَبِي الزِّنَادِ، أَخْبَرَنِي ابْنُ جَرْهَدٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ بِهِ وَهُوَ كَاشِفٌ عَنْ فَخِذِهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ غَطِّ فَخِذَكَ فَإِنَّهَا مِنَ الْعَوْرَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2798}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Az-Zinad:"Ibn Jarhad informed me from his father, that the Prophet (ﷺ) passed by him while his thigh was exposed, so the Prophet (ﷺ) said: 'Cover your thigh, for indeed it is 'Awrah}}
\hadithdefcmd{tirmidhi}{2799}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا خَالِدُ بْنُ إِلْيَاسَ، وَيُقَالُ ابْنُ إِيَاسٍ، عَنْ صَالِحِ بْنِ أَبِي حَسَّانَ، قَالَ سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ إِنَّ اللَّهَ طَيِّبٌ يُحِبُّ الطَّيِّبَ نَظِيفٌ يُحِبُّ النَّظَافَةَ كَرِيمٌ يُحِبُّ الْكَرَمَ جَوَادٌ يُحِبُّ الْجُودَ فَنَظِّفُوا أُرَاهُ قَالَ أَفْنِيَتَكُمْ وَلاَ تَشَبَّهُوا بِالْيَهُودِ ‏.‏ قَالَ فَذَكَرْتُ ذَلِكَ لِمُهَاجِرِ بْنِ مِسْمَارٍ فَقَالَ حَدَّثَنِيهِ عَامِرُ بْنُ سَعْدِ بْنِ أَبِي وَقَّاصٍ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ إِلاَّ أَنَّهُ قَالَ نَظِّفُوا أَفْنِيَتَكُمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَخَالِدُ بْنُ إِلْيَاسَ يُضَعَّفُ ‏.‏\hadithno{2799}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Salih bin Abi Hassan:"I heard Sa'eed bin Musayyab saying: 'Indeed Allah is Tayyib (good) and he loves Tayyib (what is good), and He is Nazif (clean) and He loves cleanliness, He is Karim (kind) and He loves kindness, He is Jawad (generous) and He loves generosity. So clean' - I think he said - 'your courtyards, and do not resemble the Jews.'" He said: "I mentioned that to Muhajir bin Mismar, and he said: "Amir bin Sa'd [bin Abi Waqqas] narrated it to me from his father from the Prophet (ﷺ), similarly, except that he did not say: "Clean your courtyards}}
\hadithdefcmd{tirmidhi}{2800}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ نِيْزَكَ الْبَغْدَادِيُّ، حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، حَدَّثَنَا أَبُو مُحَيَّاةَ، عَنْ لَيْثٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِيَّاكُمْ وَالتَّعَرِّي فَإِنَّ مَعَكُمْ مَنْ لاَ يُفَارِقُكُمْ إِلاَّ عِنْدَ الْغَائِطِ وَحِينَ يُفْضِي الرَّجُلُ إِلَى أَهْلِهِ فَاسْتَحْيُوهُمْ وَأَكْرِمُوهُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَأَبُو مُحَيَّاةَ اسْمُهُ يَحْيَى بْنُ يَعْلَى ‏.‏\hadithno{2800}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Muhayyah:from Laith, from Nafi, from Ibn 'Umar that the Messenger of Allah (ﷺ) said: "Beware of nakedness! For indeed there are with you, those who do not part from you except at the place of defecation, and when a man goes into his wife. So be shy of them and honor them}}
\hadithdefcmd{tirmidhi}{2801}{حَدَّثَنَا الْقَاسِمُ بْنُ دِينَارٍ الْكُوفِيُّ، حَدَّثَنَا مُصْعَبُ بْنُ الْمِقْدَامِ، عَنِ الْحَسَنِ بْنِ صَالِحٍ، عَنْ لَيْثِ بْنِ أَبِي سُلَيْمٍ، عَنْ طَاوُسٍ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلاَ يَدْخُلِ الْحَمَّامَ بِغَيْرِ إِزَارٍ وَمَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلاَ يُدْخِلْ حَلِيلَتَهُ الْحَمَّامَ وَمَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلاَ يَجْلِسْ عَلَى مَائِدَةٍ يُدَارُ عَلَيْهَا بِالْخَمْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ طَاوُسٍ عَنْ جَابِرٍ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ قَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ لَيْثُ بْنُ أَبِي سُلَيْمٍ صَدُوقٌ وَرُبَّمَا يَهِمُ فِي الشَّىْءِ ‏.‏ قَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ وَقَالَ أَحْمَدُ بْنُ حَنْبَلٍ لَيْثٌ لاَ يُفْرَحُ بِحَدِيثِهِ كَانَ لَيْثٌ يَرْفَعُ أَشْيَاءَ لاَ يَرْفَعُهَا غَيْرُهُ فَلِذَلِكَ ضَعَّفُوهُ ‏.‏\hadithno{2801}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir:that the Prophet (ﷺ) said: "Whoever believes in Allah and the Last Day, then he is not to let his wife enter the Hammam, and whoever believes in Allah and the Last Day, then he is not to enter the Hammam without an Izar. And whoever believes in Allah and the Last Day, then he is not to sit at a spread in which Khamr is circulated}}
\hadithdefcmd{tirmidhi}{2802}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ الأَعْرَجِ، عَنْ أَبِي عُذْرَةَ، وَكَانَ، قَدْ أَدْرَكَ النَّبِيَّ صلى الله عليه وسلم عَنْ عَائِشَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى الرِّجَالَ وَالنِّسَاءَ عَنِ الْحَمَّامَاتِ ثُمَّ رَخَّصَ لِلرِّجَالِ فِي الْمَيَازِرِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ حَمَّادِ بْنِ سَلَمَةَ وَإِسْنَادُهُ لَيْسَ بِذَاكَ الْقَائِمِ ‏.‏\hadithno{2802}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu 'Udhrah [and he lived during the time of the Prophet (ﷺ)]:from 'Aishah, that the Prophet (ﷺ) prohibitied the men and women from the Hammamat (plural of Hammam), then he permitted it for the men in Izar}}
\hadithdefcmd{tirmidhi}{2803}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَنْبَأَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، قَالَ سَمِعْتُ سَالِمَ بْنَ أَبِي الْجَعْدِ، يُحَدِّثُ عَنْ أَبِي الْمَلِيحِ الْهُذَلِيِّ، أَنَّ نِسَاءً، مِنْ أَهْلِ حِمْصَ أَوْ مِنْ أَهْلِ الشَّامِ دَخَلْنَ عَلَى عَائِشَةَ فَقَالَتْ أَنْتُنَّ اللاَّتِي يَدْخُلْنَ نِسَاؤُكُنَّ الْحَمَّامَاتِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنِ امْرَأَةٍ تَضَعُ ثِيَابَهَا فِي غَيْرِ بَيْتِ زَوْجِهَا إِلاَّ هَتَكَتِ السِّتْرَ بَيْنَهَا وَبَيْنَ رَبِّهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2803}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Al-Malih Al-Hudhali:that some women from the inhabitants of Hims, or from the inhabitants of Ash-Sham entered upon 'Aishah, so she said: "Are you those whose women enter the Hammamat? I heard the Messenger of Allah (ﷺ) saying: 'No woman removes her garments in other than the house of her husband except that she has torn the screen between herself and her Lord}}
\hadithdefcmd{tirmidhi}{2804}{حَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، وَالْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، وَعَبْدُ بْنُ حُمَيْدٍ، وَغَيْرُ، وَاحِدٍ، وَاللَّفْظُ، لِلْحَسَنِ بْنِ عَلِيٍّ قَالُوا حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ، يَقُولُ سَمِعْتُ أَبَا طَلْحَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ كَلْبٌ وَلاَ صُورَةُ تَمَاثِيلَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2804}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Abbas:"I heard Abu Talhah saying: 'I heard the Messenger of Allah (ﷺ) saying: "The angels do not enter a house in which there is a dog or an object of images}}
\hadithdefcmd{tirmidhi}{2805}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّ رَافِعَ بْنَ إِسْحَاقَ، أَخْبَرَهُ قَالَ دَخَلْتُ أَنَا وَعَبْدُ اللَّهِ بْنُ أَبِي طَلْحَةَ، عَلَى أَبِي سَعِيدٍ الْخُدْرِيِّ نَعُودُهُ فَقَالَ أَبُو سَعِيدٍ أَخْبَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّ الْمَلاَئِكَةَ لاَ تَدْخُلُ بَيْتًا فِيهِ تَمَاثِيلُ أَوْ صُورَةٌ ‏.‏ شَكَّ إِسْحَاقُ لاَ يَدْرِي أَيُّهُمَا قَالَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2805}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ishaq bin 'Abdullah bin Abi Talhah:that Rafi' bin Ishaq informed him, saying: "I and 'Abdullah bin Abi Talhah entered upon Abu Sa'eed Al-Khudri to visit him. So Abu Sa'eed said: 'The Messenger of Allah (ﷺ) informed us: "The angels do not enter a house in which there is an image or a picture}}
\hadithdefcmd{tirmidhi}{2806}{حَدَّثَنَا سُوَيْدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، حَدَّثَنَا مُجَاهِدٌ، قَالَ حَدَّثَنَا أَبُو هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَتَانِي جِبْرِيلُ فَقَالَ إِنِّي كُنْتُ أَتَيْتُكَ الْبَارِحَةَ فَلَمْ يَمْنَعْنِي أَنْ أَكُونَ دَخَلْتُ عَلَيْكَ الْبَيْتَ الَّذِي كُنْتَ فِيهِ إِلاَّ أَنَّهُ كَانَ فِي بَابِ الْبَيْتِ تِمْثَالُ الرِّجَالِ وَكَانَ فِي الْبَيْتِ قِرَامُ سِتْرٍ فِيهِ تَمَاثِيلُ وَكَانَ فِي الْبَيْتِ كَلْبٌ فَمُرْ بِرَأْسِ التِّمْثَالِ الَّذِي بِالْبَابِ فَلْيُقْطَعْ فَيَصِيرَ كَهَيْئَةِ الشَّجَرَةِ وَمُرْ بِالسِّتْرِ فَلْيُقْطَعْ وَيُجْعَلْ مِنْهُ وِسَادَتَيْنِ مُنْتَبَذَتَيْنِ يُوَطَآنِ وَمُرْ بِالْكَلْبِ فَيُخْرَجْ ‏"‏ ‏.‏ فَفَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَانَ ذَلِكَ الْكَلْبُ جَرْوًا لِلْحَسَنِ أَوِ الْحُسَيْنِ تَحْتَ نَضَدٍ لَهُ فَأَمَرَ بِهِ فَأُخْرِجَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأَبِي طَلْحَةَ ‏.‏\hadithno{2806}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Jibra'il came to me and said: "Indeed I had come to you last night, and nothing prevented me from entering upon you at the house you were in, except that there were images of men at the door of the house, and there was a curtain screen with imagines on it, and there was a dog in the house. So go and sever the head of the image that is at the door so that it will become like a tree stump, and go and cut the screen and make two throw-cushions to be sat upon, and go and expel the dog." So the Messenger of Allah (ﷺ) did so, and the dog was a puppy belonging to Al-Husain or Al-Hasan which was under his belongings, so he ordered him to expel it}}
\hadithdefcmd{tirmidhi}{2807}{حَدَّثَنَا عَبَّاسُ بْنُ مُحَمَّدٍ الْبَغْدَادِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا إِسْرَائِيلُ، عَنْ أَبِي يَحْيَى، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ مَرَّ رَجُلٌ وَعَلَيْهِ ثَوْبَانِ أَحْمَرَانِ فَسَلَّمَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَلَمْ يَرُدَّ النَّبِيُّ صلى الله عليه وسلم عَلَيْهِ السَّلاَمَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَمَعْنَى هَذَا الْحَدِيثِ عِنْدَ أَهْلِ الْعِلْمِ أَنَّهُمْ كَرِهُوا لُبْسَ الْمُعَصْفَرِ وَرَأَوْا أَنَّ مَا صُبِغَ بِالْحُمْرَةِ بِالْمَدَرِ أَوْ غَيْرِ ذَلِكَ فَلاَ بَأْسَ بِهِ إِذَا لَمْ يَكُنْ مُعَصْفَرًا ‏.‏\hadithno{2807}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdullah bin 'Amr:"A man passed by while wearing two red garments. He gave Salam to the Prophet (ﷺ) but he did not return the Salam}}
\hadithdefcmd{tirmidhi}{2808}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ هُبَيْرَةَ بْنِ يَرِيمَ، قَالَ قَالَ عَلِيُّ بْنُ أَبِي طَالِبٍ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ خَاتِمِ الذَّهَبِ وَعَنِ الْقَسِّيِّ وَعَنِ الْمِيثَرَةِ وَعَنِ الْجَعَةِ ‏.‏ قَالَ أَبُو الأَحْوَصِ وَهُوَ شَرَابٌ يُتَّخَذُ بِمِصْرَ مِنَ الشَّعِيرِ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2808}\hadithgrade{Ahmad Muhammad Shakir: Sahih Matn; Al-Albani: Sahih Matn; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Ali bin Abi Talib:"The Messenger of Allah (ﷺ) prohibited the gold ring, Al-Qassi, Al-Mitharah, and Al-Ji'ah (beer)}}
\hadithdefcmd{tirmidhi}{2809}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنِ الأَشْعَثِ بْنِ سُلَيْمٍ، عَنْ مُعَاوِيَةَ بْنِ سُوَيْدِ بْنِ مُقَرِّنٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِسَبْعٍ وَنَهَانَا عَنْ سَبْعٍ أَمَرَنَا بِاتِّبَاعِ الْجَنَازَةِ وَعِيَادَةِ الْمَرِيضِ وَتَشْمِيتِ الْعَاطِسِ وَإِجَابَةِ الدَّاعِي وَنَصْرِ الْمَظْلُومِ وَإِبْرَارِ الْقَسَمِ وَرَدِّ السَّلاَمِ وَنَهَانَا عَنْ سَبْعٍ عَنْ خَاتِمِ الذَّهَبِ أَوْ حَلْقَةِ الذَّهَبِ وَآنِيَةِ الْفِضَّةِ وَلُبْسِ الْحَرِيرِ وَالدِّيبَاجِ وَالإِسْتَبْرَقِ وَالْقَسِّيِّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَشْعَثُ بْنُ سُلَيْمٍ هُوَ أَشْعَثُ بْنُ أَبِي الشَّعْثَاءِ وَأَبُو الشَّعْثَاءِ اسْمُهُ سُلَيْمُ بْنُ الأَسْوَدِ ‏.‏\hadithno{2809}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Al-Bara bin 'Azib:"The Messenger of Allah (ﷺ) ordered us with seven things and he forbade us from seven. He ordered us to follow the funeral, visit the ill, reply to the sneezing person, accept the invitation, assist the oppressed, to help the one who made an oath, and to return the Salam. And he forbade us from seven things: From the gold ring, or ringlets of gold, silver vessels, wearing silk, Ad-Dibaj, Al-Istabraq, And Al-Qassi}}
\hadithdefcmd{tirmidhi}{2810}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ مَيْمُونِ بْنِ أَبِي شَبِيبٍ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْبَسُوا الْبَيَاضَ فَإِنَّهَا أَطْهَرُ وَأَطْيَبُ وَكَفِّنُوا فِيهَا مَوْتَاكُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَابْنِ عُمَرَ ‏.‏\hadithno{2810}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Samurah bin Jundab:"The Messenger of Allah (ﷺ) said: 'Wear white, for indeed it is very pure and cleaner, and shroud your dead in it}}
\hadithdefcmd{tirmidhi}{2811}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْثَرُ بْنُ الْقَاسِمِ، عَنِ الأَشْعَثِ، وَهُوَ ابْنُ سَوَّارٍ عَنْ أَبِي إِسْحَاقَ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي لَيْلَةٍ إِضْحِيَانٍ فَجَعَلْتُ أَنْظُرُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَإِلَى الْقَمَرِ وَعَلَيْهِ حُلَّةٌ حَمْرَاءُ فَإِذَا هُوَ عِنْدِي أَحْسَنُ مِنَ الْقَمَرِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الأَشْعَثِ ‏.‏\hadithno{2811}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir Bin Samurah:"I saw the Prophet (ﷺ) on a clear night, so I looked at the Messenger of Allah (ﷺ) and at the moon, and he was wearing a red Hullah, and he looked better than the moon to me}}
\hadithdefcmd{tirmidhi}{2811p2}{وَرَوَى شُعْبَةُ، وَالثَّوْرِيُّ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ رَأَيْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم حُلَّةً حَمْرَاءَ ‏.‏ حَدَّثَنَا بِذَلِكَ مَحْمُودُ بْنُ غَيْلاَنَ حَدَّثَنَا وَكِيعٌ حَدَّثَنَا سُفْيَانُ عَنْ أَبِي إِسْحَاقَ وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا مَحَمَّدُ بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ عَنْ أَبِي إِسْحَاقَ بِهَذَا ‏.‏ وَفِي الْحَدِيثِ كَلاَمٌ أَكْثَرُ مِنْ هَذَا ‏.‏ قَالَ سَأَلْتُ مُحَمَّدًا قُلْتُ لَهُ حَدِيثُ أَبِي إِسْحَاقَ عَنِ الْبَرَاءِ أَصَحُّ أَوْ حَدِيثُ جَابِرِ بْنِ سَمُرَةَ فَرَأَى كِلاَ الْحَدِيثَيْنِ صَحِيحًا ‏.‏ وَفِي الْبَابِ عَنِ الْبَرَاءِ وَأَبِي جُحَيْفَةَ ‏.‏\hadithno{2811.2}\hadithtrans{Shu'bah and Ath-Thawri reported it from Abu Ishaq from Al-Bara bin 'Azib who said:"I saw a red Hullah on the Messenger of Allah." (Another chain of narration)}}
\hadithdefcmd{tirmidhi}{2812}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ إِيَادِ بْنِ لَقِيطٍ، عَنْ أَبِيهِ، عَنْ أَبِي رِمْثَةَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَعَلَيْهِ بُرْدَانِ أَخْضَرَانِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عُبَيْدِ اللَّهِ بْنِ إِيَادٍ ‏.‏ وَأَبُو رِمْثَةَ التَّيْمِيُّ يُقَالُ اسْمُهُ حَبِيبُ بْنُ حَيَّانَ وَيُقَالُ اسْمُهُ رِفَاعَةُ بْنُ يَثْرِبِيٍّ ‏.‏\hadithno{2812}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Rimthah:"I saw the Messenger of Allah wearing two green Burud}}
\hadithdefcmd{tirmidhi}{2813}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، أَخْبَرَنِي أَبِي، عَنْ مُصْعَبِ بْنِ شَيْبَةَ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ، قَالَتْ خَرَجَ النَّبِيُّ صلى الله عليه وسلم ذَاتَ غَدَاةٍ وَعَلَيْهِ مِرْطٌ مِنْ شَعَرٍ أَسْوَدَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{2813}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Aishah:"The Messenger of Allah (ﷺ) went out during the morning wearing a Mirt made of black hair}}
\hadithdefcmd{tirmidhi}{2814}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ الصَّفَّارُ أَبُو عُثْمَانَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ حَسَّانَ، أَنَّهُ حَدَّثَتْهُ جَدَّتَاهُ، صَفِيَّةُ بِنْتُ عُلَيْبَةَ وَدُحَيْبَةُ بِنْتُ عُلَيْبَةَ حَدَّثَتَاهُ عَنْ قَيْلَةَ بِنْتِ مَخْرَمَةَ، وَكَانَتَا، رَبِيبَتَيْهَا وَقَيْلَةُ جَدَّةُ أَبِيهِمَا أُمُّ أُمِّهِ أَنَّهَا قَالَتْ قَدِمْنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَتِ الْحَدِيثَ بِطُولِهِ حَتَّى جَاءَ رَجُلٌ وَقَدِ ارْتَفَعَتِ الشَّمْسُ فَقَالَ السَّلاَمُ عَلَيْكَ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَعَلَيْكَ السَّلاَمُ وَرَحْمَةُ اللَّهِ ‏"‏ ‏.‏ وَعَلَيْهِ تَعْنِي النَّبِيَّ صلى الله عليه وسلم - أَسْمَالُ مُلَيَّتَيْنِ كَانَتَا بِزَعْفَرَانٍ وَقَدْ نَفَضَتَا وَمَعَ النَّبِيِّ صلى الله عليه وسلم عُسَيْبُ نَخْلَةٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ قَيْلَةَ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ اللَّهِ بْنِ حَسَّانَ ‏.‏\hadithno{2814}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdullah bin Hassan:that his grandmothers Safiyyah bint 'Ulaibah and Dhuhaibah bint 'Ulaibah narrated to him, from Qailah bint Makhramah - and they were her wet nurses and Qailah was the grandmother of their father - his mother's mother - she said: "We came to the Messenger of Allah (ﷺ)" and she mentioned the Hadith in its entirety; "until a man came when the sun had rose up, so he said: "As-Salamu 'Alaika O Messenger of Allah!' So the Messenger of Allah (ﷺ) said: 'Wa 'Alaikas-Salamu Wa Rahmatullah' and upon him - meaning the Prophet (ﷺ) - were two tattered cloths, which had been dyed with saffron and had faded, and he had a small date-palm branch with him}}
\hadithdefcmd{tirmidhi}{2815}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، قَالَ ح وَحَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ حَمَّادِ بْنِ زَيْدٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ التَّزَعْفُرِ لِلرِّجَالِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى شُعْبَةُ، هَذَا الْحَدِيثَ عَنْ إِسْمَاعِيلَ ابْنِ عُلَيَّةَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ التَّزَعْفُرِ ‏.‏ حَدَّثَنَا بِذَلِكَ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ حَدَّثَنَا آدَمُ عَنْ شُعْبَةَ ‏.‏ قَالَ أَبُو عِيسَى وَمَعْنَى كَرَاهِيَةِ التَّزَعْفُرِ لِلرِّجَالِ أَنْ يَتَزَعْفَرَ الرَّجُلُ يَعْنِي أَنْ يَتَطَيَّبَ بِهِ ‏.‏\hadithno{2815}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Anas bin Malik:that the Messenger of Allah (ﷺ) prohibited saffron for men}}
\hadithdefcmd{tirmidhi}{2815p2}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، قَالَ ح وَحَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ حَمَّادِ بْنِ زَيْدٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ التَّزَعْفُرِ لِلرِّجَالِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى شُعْبَةُ، هَذَا الْحَدِيثَ عَنْ إِسْمَاعِيلَ ابْنِ عُلَيَّةَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ التَّزَعْفُرِ ‏.‏ حَدَّثَنَا بِذَلِكَ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ حَدَّثَنَا آدَمُ عَنْ شُعْبَةَ ‏.‏ قَالَ أَبُو عِيسَى وَمَعْنَى كَرَاهِيَةِ التَّزَعْفُرِ لِلرِّجَالِ أَنْ يَتَزَعْفَرَ الرَّجُلُ يَعْنِي أَنْ يَتَطَيَّبَ بِهِ ‏.‏\hadithno{2815.2}\hadithtrans{Narrated Anas bin Malik:that the Messenger of Allah (ﷺ) prohibited saffron for men}}
\hadithdefcmd{tirmidhi}{2816}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، عَنْ شُعْبَةَ، عَنْ عَطَاءِ بْنِ السَّائِبِ، قَالَ سَمِعْتُ أَبَا حَفْصِ بْنَ عُمَرَ، يُحَدِّثُ عَنْ يَعْلَى بْنِ مُرَّةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَبْصَرَ رَجُلاً مُتَخَلِّقًا قَالَ ‏ "‏ اذْهَبْ فَاغْسِلْهُ ثُمَّ اغْسِلْهُ ثُمَّ لاَ تَعُدْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدِ اخْتَلَفَ بَعْضُهُمْ فِي هَذَا الإِسْنَادِ عَنْ عَطَاءِ بْنِ السَّائِبِ ‏.‏ قَالَ عَلِيٌّ قَالَ يَحْيَى بْنُ سَعِيدٍ مَنْ سَمِعَ مِنْ عَطَاءِ بْنِ السَّائِبِ قَدِيمًا فَسَمَاعُهُ صَحِيحٌ وَسَمَاعُ شُعْبَةَ وَسُفْيَانَ مِنْ عَطَاءِ بْنِ السَّائِبِ صَحِيحٌ إِلاَّ حَدِيثَيْنِ عَنْ عَطَاءِ بْنِ السَّائِبِ عَنْ زَاذَانَ قَالَ شُعْبَةُ سَمِعْتُهُمَا مِنْهُ بِأَخَرَةٍ ‏.‏ قَالَ أَبُو عِيسَى يُقَالُ إِنَّ عَطَاءَ بْنَ السَّائِبِ كَانَ فِي آخِرِ أَمْرِهِ قَدْ سَاءَ حِفْظُهُ ‏.‏ وَفِي الْبَابِ عَنْ عَمَّارٍ وَأَبِي مُوسَى وَأَنَسٍ وَأَبُو حَفْصٍ هُوَ أَبُو حَفْصِ بْنُ عُمَرَ ‏.‏\hadithno{2816}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ya'la bin Murrah:"The Prophet (ﷺ) saw a man wearing Khuluq and said: 'Go and wash it, then wash it, then do not use it again}}
\hadithdefcmd{tirmidhi}{2817}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ الأَزْرَقُ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، حَدَّثَنِي مَوْلَى، أَسْمَاءَ عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ عُمَرَ، يَذْكُرُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَبِسَ الْحَرِيرَ فِي الدُّنْيَا لَمْ يَلْبَسْهُ فِي الآخِرَةِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَحُذَيْفَةَ وَأَنَسٍ وَغَيْرِ وَاحِدٍ وَقَدْ ذَكَرْنَاهُ فِي كِتَابِ اللِّبَاسِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ قَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ عُمَرَ ‏.‏ وَمَوْلَى أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ الصِّدِّيقِ اسْمُهُ عَبْدُ اللَّهِ وَيُكْنَى أَبَا عُمَرَ وَقَدْ رَوَى عَنْهُ عَطَاءُ بْنُ أَبِي رَبَاحٍ وَعَمْرُو بْنُ دِينَارٍ ‏.‏\hadithno{2817}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated The freed slave of Asma:from Ibn 'Umar who said: "I heard 'Umar mentioning that the Prophet (ﷺ) said: 'Whoever wears silk in the world he shall not wear it in the Hereafter}}
\hadithdefcmd{tirmidhi}{2818}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَسَمَ أَقْبِيَةً وَلَمْ يُعْطِ مَخْرَمَةَ شَيْئًا فَقَالَ مَخْرَمَةُ يَا بُنَىَّ انْطَلِقْ بِنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَانْطَلَقْتُ مَعَهُ قَالَ ادْخُلْ فَادْعُهُ لِي فَدَعَوْتُهُ لَهُ فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم وَعَلَيْهِ قِبَاءٌ مِنْهَا فَقَالَ ‏"‏ خَبَأْتُ لَكَ هَذَا ‏"‏ ‏.‏ قَالَ فَنَظَرَ إِلَيْهِ فَقَالَ ‏"‏ رَضِيَ مَخْرَمَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَابْنُ أَبِي مُلَيْكَةَ اسْمُهُ عَبْدُ اللَّهِ بْنُ عُبَيْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ ‏.‏\hadithno{2818}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Al-Miswar bin Makhramah:"The Messenger of Allah (ﷺ) distributed some cloaks but he did not give anything to Makhramah. Makhramah said: 'O my son! Let us go to the Messenger of Allah (ﷺ).' So I went with him. He said: 'Enter and call him for me.'So I called the Prophet (ﷺ) for him, then the Prophet (ﷺ) came out wearing one of the cloaks. He (ﷺ) said: 'I kept this one for you.'" He said: "So he looked at him and said: 'Makhramah is pleased}}
\hadithdefcmd{tirmidhi}{2819}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يُحِبَّ أَنْ يُرَى أَثَرُ نِعْمَتِهِ عَلَى عَبْدِهِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي الأَحْوَصِ عَنْ أَبِيهِ وَعِمْرَانَ بْنِ حُصَيْنٍ وَابْنِ مَسْعُودٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2819}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Amr bin Shu'aib:from his father, from his grandfather who said: "The Messenger of Allah (ﷺ) said: 'Indeed Allah loves to see the results of his favors upon His Slaves}}
\hadithdefcmd{tirmidhi}{2820}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ دَلْهَمِ بْنِ صَالِحٍ، عَنْ حُجَيْرِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ النَّجَاشِيَّ، أَهْدَى إِلَى النَّبِيِّ صلى الله عليه وسلم خُفَّيْنِ أَسْوَدَيْنِ سَاذَجَيْنِ فَلَبِسَهُمَا ثُمَّ تَوَضَّأَ وَمَسَحَ عَلَيْهِمَا ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ دَلْهَمٍ وَقَدْ رَوَاهُ مُحَمَّدُ بْنُ رَبِيعَةَ عَنْ دَلْهَمٍ ‏.‏\hadithno{2820}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn Buraidah:from his father: "An-Najashi gave the Prophet (ﷺ) two black plain Khuff. So he wore them, then he performed Wudu and wiped over them}}
\hadithdefcmd{tirmidhi}{2821}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، حَدَّثَنَا عَبْدَةُ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ نَتْفِ الشَّيْبِ وَقَالَ ‏ "‏ إِنَّهُ نُورُ الْمُسْلِمِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ قَدْ رُوِيَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ وَغَيْرِ وَاحِدٍ عَنْ عَمْرِو بْنِ شُعَيْبٍ ‏.‏\hadithno{2821}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Amr bin Shu'aib:from his father, from his grandfather: "The Prophet (ﷺ) prohibited plucking gray hair. And he said: "It is the Muslim's light}}
\hadithdefcmd{tirmidhi}{2822}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا شَيْبَانُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُسْتَشَارُ مُؤْتَمَنٌ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَى غَيْرُ وَاحِدٍ عَنْ شَيْبَانَ بْنِ عَبْدِ الرَّحْمَنِ النَّحْوِيِّ وَشَيْبَانُ هُوَ صَاحِبُ كِتَابٍ وَهُوَ صَحِيحُ الْحَدِيثِ وَيُكْنَى أَبَا مُعَاوِيَةَ ‏.‏ حَدَّثَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ الْعَطَّارُ عَنْ سُفْيَانَ بْنِ عُيَيْنَةَ قَالَ قَالَ عَبْدُ الْمَلِكِ بْنُ عُمَيْرٍ إِنِّي لأُحَدِّثُ الْحَدِيثَ فَمَا أَدَعُ مِنْهُ حَرْفًا ‏.‏\hadithno{2822}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "The one whose counsel is sought is entrusted}}
\hadithdefcmd{tirmidhi}{2823}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ دَاوُدَ بْنِ أَبِي عَبْدِ اللَّهِ، عَنِ ابْنِ جُدْعَانَ، عَنْ جَدَّتِهِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُسْتَشَارُ مُؤْتَمَنٌ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَأَبِي هُرَيْرَةَ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ أُمِّ سَلَمَةَ ‏.‏\hadithno{2823}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umm Salamah:"The Messenger of Allah (ﷺ) said: 'The one whose council is sought is entrusted}}
\hadithdefcmd{tirmidhi}{2824}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، وَحَمْزَةَ، ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِمَا، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الشُّؤْمُ فِي ثَلاَثَةٍ فِي الْمَرْأَةِ وَالْمَسْكَنِ وَالدَّابَّةِ ‏". ‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَبَعْضُ أَصْحَابِ الزُّهْرِيِّ لاَ يَذْكُرُونَ فِيهِ عَنْ حَمْزَةَ إِنَّمَا يَقُولُونَ عَنْ سَالِمٍ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَى مَالِكُ بْنُ أَنَسٍ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ فَقَالَ عَنْ سَالِمٍ وَحَمْزَةَ ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِمَا وَهَكَذَا رَوَى لَنَا ابْنُ أَبِي عُمَرَ هَذَا الْحَدِيثَ عَنْ سُفْيَانَ بْنِ عُيَيْنَةَ عَنِ الزُّهْرِيِّ عَنْ سَالِمٍ وَحَمْزَةَ ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِمَا عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ وَلَمْ يَذْكُرْ فِيهِ سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ عَنْ حَمْزَةَ، وَرِوَايَةُ، سَعِيدٍ أَصَحُّ لأَنَّ عَلِيَّ بْنَ الْمَدِينِيِّ وَالْحُمَيْدِيَّ رَوَيَا عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، وَذَكَرَا، عَنْ سُفْيَانَ، قَالَ لَمْ يَرْوِ لَنَا الزُّهْرِيُّ هَذَا الْحَدِيثَ إِلاَّ عَنْ سَالِمٍ عَنِ ابْنِ عُمَرَ ‏.‏ وَرَوَى مَالِكُ بْنُ أَنَسٍ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ وَقَالَ عَنْ سَالِمٍ وَحَمْزَةَ ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِمَا ‏.‏ وَفِي الْبَابِ عَنْ سَهْلِ بْنِ سَعْدٍ وَعَائِشَةَ وَأَنَسٍ ‏.‏ - وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ إِنْ كَانَ الشُّؤْمُ فِي شَيْءٍ فَفِي الْمَرْأَةِ وَالدَّابَّةِ وَالْمَسْكَنِ ‏"‏ ‏.‏ وَقَدْ رُوِيَ عَنْ حَكِيمِ بْنِ مُعَاوِيَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ شُؤْمَ وَقَدْ يَكُونُ الْيُمْنُ فِي الدَّارِ وَالْمَرْأَةِ وَالْفَرَسِ ‏"‏ ‏.‏ حَدَّثَنَا بِذَلِكَ عَلِيُّ بْنُ حُجْرٍ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ عَنْ سُلَيْمَانَ بْنِ سُلَيْمٍ عَنْ يَحْيَى بْنِ جَابِرٍ الطَّائِيِّ عَنْ مُعَاوِيَةَ بْنِ حَكِيمٍ عَنْ عَمِّهِ حَكِيمِ بْنِ مُعَاوِيَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا ‏.‏\hadithno{2824}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Salim and Hamzah, the sons of 'Abdullah bin 'Umar:from their father that the Messenger of Allah (ﷺ) said: "An omen is in three: A woman, a dwelling, and a (riding) beast}}
\hadithdefcmd{tirmidhi}{2824p2}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، وَحَمْزَةَ، ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِمَا، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الشُّؤْمُ فِي ثَلاَثَةٍ فِي الْمَرْأَةِ وَالْمَسْكَنِ وَالدَّابَّةِ ‏". ‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَبَعْضُ أَصْحَابِ الزُّهْرِيِّ لاَ يَذْكُرُونَ فِيهِ عَنْ حَمْزَةَ إِنَّمَا يَقُولُونَ عَنْ سَالِمٍ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَى مَالِكُ بْنُ أَنَسٍ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ فَقَالَ عَنْ سَالِمٍ وَحَمْزَةَ ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِمَا وَهَكَذَا رَوَى لَنَا ابْنُ أَبِي عُمَرَ هَذَا الْحَدِيثَ عَنْ سُفْيَانَ بْنِ عُيَيْنَةَ عَنِ الزُّهْرِيِّ عَنْ سَالِمٍ وَحَمْزَةَ ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِمَا عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ وَلَمْ يَذْكُرْ فِيهِ سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ عَنْ حَمْزَةَ، وَرِوَايَةُ، سَعِيدٍ أَصَحُّ لأَنَّ عَلِيَّ بْنَ الْمَدِينِيِّ وَالْحُمَيْدِيَّ رَوَيَا عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، وَذَكَرَا، عَنْ سُفْيَانَ، قَالَ لَمْ يَرْوِ لَنَا الزُّهْرِيُّ هَذَا الْحَدِيثَ إِلاَّ عَنْ سَالِمٍ عَنِ ابْنِ عُمَرَ ‏.‏ وَرَوَى مَالِكُ بْنُ أَنَسٍ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ وَقَالَ عَنْ سَالِمٍ وَحَمْزَةَ ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِمَا ‏.‏ وَفِي الْبَابِ عَنْ سَهْلِ بْنِ سَعْدٍ وَعَائِشَةَ وَأَنَسٍ ‏.‏ - وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ إِنْ كَانَ الشُّؤْمُ فِي شَيْءٍ فَفِي الْمَرْأَةِ وَالدَّابَّةِ وَالْمَسْكَنِ ‏"‏ ‏.‏ وَقَدْ رُوِيَ عَنْ حَكِيمِ بْنِ مُعَاوِيَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ شُؤْمَ وَقَدْ يَكُونُ الْيُمْنُ فِي الدَّارِ وَالْمَرْأَةِ وَالْفَرَسِ ‏"‏ ‏.‏ حَدَّثَنَا بِذَلِكَ عَلِيُّ بْنُ حُجْرٍ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ عَنْ سُلَيْمَانَ بْنِ سُلَيْمٍ عَنْ يَحْيَى بْنِ جَابِرٍ الطَّائِيِّ عَنْ مُعَاوِيَةَ بْنِ حَكِيمٍ عَنْ عَمِّهِ حَكِيمِ بْنِ مُعَاوِيَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا ‏.‏\hadithno{2824.2}\hadithtrans{Narrated Salim and Hamzah, the sons of 'Abdullah bin 'Umar:from their father that the Messenger of Allah (ﷺ) said: "An omen is in three: A woman, a dwelling, and a (riding) beast}}
\hadithdefcmd{tirmidhi}{2824p3}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، وَحَمْزَةَ، ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِمَا، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الشُّؤْمُ فِي ثَلاَثَةٍ فِي الْمَرْأَةِ وَالْمَسْكَنِ وَالدَّابَّةِ ‏". ‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَبَعْضُ أَصْحَابِ الزُّهْرِيِّ لاَ يَذْكُرُونَ فِيهِ عَنْ حَمْزَةَ إِنَّمَا يَقُولُونَ عَنْ سَالِمٍ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَى مَالِكُ بْنُ أَنَسٍ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ فَقَالَ عَنْ سَالِمٍ وَحَمْزَةَ ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِمَا وَهَكَذَا رَوَى لَنَا ابْنُ أَبِي عُمَرَ هَذَا الْحَدِيثَ عَنْ سُفْيَانَ بْنِ عُيَيْنَةَ عَنِ الزُّهْرِيِّ عَنْ سَالِمٍ وَحَمْزَةَ ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِمَا عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ وَلَمْ يَذْكُرْ فِيهِ سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ عَنْ حَمْزَةَ، وَرِوَايَةُ، سَعِيدٍ أَصَحُّ لأَنَّ عَلِيَّ بْنَ الْمَدِينِيِّ وَالْحُمَيْدِيَّ رَوَيَا عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، وَذَكَرَا، عَنْ سُفْيَانَ، قَالَ لَمْ يَرْوِ لَنَا الزُّهْرِيُّ هَذَا الْحَدِيثَ إِلاَّ عَنْ سَالِمٍ عَنِ ابْنِ عُمَرَ ‏.‏ وَرَوَى مَالِكُ بْنُ أَنَسٍ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ وَقَالَ عَنْ سَالِمٍ وَحَمْزَةَ ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِمَا ‏.‏ وَفِي الْبَابِ عَنْ سَهْلِ بْنِ سَعْدٍ وَعَائِشَةَ وَأَنَسٍ ‏.‏ - وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ إِنْ كَانَ الشُّؤْمُ فِي شَيْءٍ فَفِي الْمَرْأَةِ وَالدَّابَّةِ وَالْمَسْكَنِ ‏"‏ ‏.‏ وَقَدْ رُوِيَ عَنْ حَكِيمِ بْنِ مُعَاوِيَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ شُؤْمَ وَقَدْ يَكُونُ الْيُمْنُ فِي الدَّارِ وَالْمَرْأَةِ وَالْفَرَسِ ‏"‏ ‏.‏ حَدَّثَنَا بِذَلِكَ عَلِيُّ بْنُ حُجْرٍ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ عَنْ سُلَيْمَانَ بْنِ سُلَيْمٍ عَنْ يَحْيَى بْنِ جَابِرٍ الطَّائِيِّ عَنْ مُعَاوِيَةَ بْنِ حَكِيمٍ عَنْ عَمِّهِ حَكِيمِ بْنِ مُعَاوِيَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا ‏.‏\hadithno{2824.3}\hadithtrans{Narrated Salim and Hamzah, the sons of 'Abdullah bin 'Umar:from their father that the Messenger of Allah (ﷺ) said: "An omen is in three: A woman, a dwelling, and a (riding) beast}}
\hadithdefcmd{tirmidhi}{2824p4}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، وَحَمْزَةَ، ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِمَا، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الشُّؤْمُ فِي ثَلاَثَةٍ فِي الْمَرْأَةِ وَالْمَسْكَنِ وَالدَّابَّةِ ‏". ‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَبَعْضُ أَصْحَابِ الزُّهْرِيِّ لاَ يَذْكُرُونَ فِيهِ عَنْ حَمْزَةَ إِنَّمَا يَقُولُونَ عَنْ سَالِمٍ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَى مَالِكُ بْنُ أَنَسٍ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ فَقَالَ عَنْ سَالِمٍ وَحَمْزَةَ ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِمَا وَهَكَذَا رَوَى لَنَا ابْنُ أَبِي عُمَرَ هَذَا الْحَدِيثَ عَنْ سُفْيَانَ بْنِ عُيَيْنَةَ عَنِ الزُّهْرِيِّ عَنْ سَالِمٍ وَحَمْزَةَ ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِمَا عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ وَلَمْ يَذْكُرْ فِيهِ سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ عَنْ حَمْزَةَ، وَرِوَايَةُ، سَعِيدٍ أَصَحُّ لأَنَّ عَلِيَّ بْنَ الْمَدِينِيِّ وَالْحُمَيْدِيَّ رَوَيَا عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، وَذَكَرَا، عَنْ سُفْيَانَ، قَالَ لَمْ يَرْوِ لَنَا الزُّهْرِيُّ هَذَا الْحَدِيثَ إِلاَّ عَنْ سَالِمٍ عَنِ ابْنِ عُمَرَ ‏.‏ وَرَوَى مَالِكُ بْنُ أَنَسٍ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ وَقَالَ عَنْ سَالِمٍ وَحَمْزَةَ ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِمَا ‏.‏ وَفِي الْبَابِ عَنْ سَهْلِ بْنِ سَعْدٍ وَعَائِشَةَ وَأَنَسٍ ‏.‏ - وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ إِنْ كَانَ الشُّؤْمُ فِي شَيْءٍ فَفِي الْمَرْأَةِ وَالدَّابَّةِ وَالْمَسْكَنِ ‏"‏ ‏.‏ وَقَدْ رُوِيَ عَنْ حَكِيمِ بْنِ مُعَاوِيَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ شُؤْمَ وَقَدْ يَكُونُ الْيُمْنُ فِي الدَّارِ وَالْمَرْأَةِ وَالْفَرَسِ ‏"‏ ‏.‏ حَدَّثَنَا بِذَلِكَ عَلِيُّ بْنُ حُجْرٍ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ عَنْ سُلَيْمَانَ بْنِ سُلَيْمٍ عَنْ يَحْيَى بْنِ جَابِرٍ الطَّائِيِّ عَنْ مُعَاوِيَةَ بْنِ حَكِيمٍ عَنْ عَمِّهِ حَكِيمِ بْنِ مُعَاوِيَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا ‏.‏\hadithno{2824.4}\hadithtrans{Narrated Salim and Hamzah, the sons of 'Abdullah bin 'Umar:from their father that the Messenger of Allah (ﷺ) said: "An omen is in three: A woman, a dwelling, and a (riding) beast}}
\hadithdefcmd{tirmidhi}{2825}{حَدَّثَنَا هَنَّادٌ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، ح قَالَ وَحَدَّثَنِي ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا كُنْتُمْ ثَلاَثَةً فَلاَ يَتَنَاجَى اثْنَانِ دُونَ صَاحِبِهِمَا ‏"‏ ‏.‏ وَقَالَ سُفْيَانُ فِي حَدِيثِهِ ‏"‏ لاَ يَتَنَاجَى اثْنَانِ دُونَ الثَّالِثِ فَإِنَّ ذَلِكَ يُحْزِنُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ - وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ لاَ يَتَنَاجَى اثْنَانِ دُونَ وَاحِدٍ فَإِنَّ ذَلِكَ يُؤْذِي الْمُؤْمِنَ وَاللَّهُ عَزَّ وَجَلَّ يَكْرَهُ أَذَى الْمُؤْمِنِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ ‏.‏\hadithno{2825}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah:that the Messenger of Allah (ﷺ) said: "Whenever there are three of you, then let two not converse in exclusion of their companion}}
\hadithdefcmd{tirmidhi}{2826}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى الْكُوفِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ أَبِي جُحَيْفَةَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَبْيَضَ قَدْ شَابَ وَكَانَ الْحَسَنُ بْنُ عَلِيٍّ يُشْبِهُهُ وَأَمَرَ لَنَا بِثَلاَثَةَ عَشَرَ قَلُوصًا فَذَهَبْنَا نَقْبِضُهَا فَأَتَانَا مَوْتُهُ فَلَمْ يُعْطُونَا شَيْئًا فَلَمَّا قَامَ أَبُو بَكْرٍ قَالَ مَنْ كَانَتْ لَهُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم عِدَةٌ فَلْيَجِئْ ‏.‏ فَقُمْتُ إِلَيْهِ فَأَخْبَرْتُهُ فَأَمَرَ لَنَا بِهَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَى مَرْوَانُ بْنُ مُعَاوِيَةَ هَذَا الْحَدِيثَ بِإِسْنَادٍ لَهُ عَنْ أَبِي جُحَيْفَةَ نَحْوَ هَذَا ‏.‏ وَقَدْ رَوَى غَيْرُ وَاحِدٍ عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ عَنْ أَبِي جُحَيْفَةَ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَكَانَ الْحَسَنُ بْنُ عَلِيٍّ يُشْبِهُهُ وَلَمْ يَزِيدُوا عَلَى هَذَا ‏.‏\hadithno{2826}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Isma'il bin Abi Khalid:that Abu Juhaifah said: "I saw the Messenger of Allah (ﷺ) (he was) white and turning grey. Al-Hasan bin 'Ali resembles him most. He had promised thirteen young she-camels for us, so we went to get them. When we arrived he had died without giving us anything. So when Abu Bakr (became the Khalifah) he said: 'If there is anyone to whom the Messenger of Allah (ﷺ) made a promise, then let him come forth.' I stood to inform him about it, and he ordered that they be given to us}}
\hadithdefcmd{tirmidhi}{2827}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، حَدَّثَنَا أَبُو جُحَيْفَةَ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَكَانَ الْحَسَنُ بْنُ عَلِيٍّ يُشْبِهُهُ ‏.‏ قَالَ أَبُو عِيسَى وَهَكَذَا رَوَى غَيْرُ وَاحِدٍ عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ نَحْوَ هَذَا ‏.‏ وَفِي الْبَابِ عَنْ جَابِرٍ ‏.‏ وَأَبُو جُحَيْفَةَ اسْمُهُ وَهْبٌ السُّوَائِيُّ ‏.‏\hadithno{2827}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Isma'il bin Abi Khalid:that Abu Juhaifah said: "I saw the Prophet (ﷺ), and Al-Hasan bin 'Ali resembles him the most}}
\hadithdefcmd{tirmidhi}{2828}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَلِيٍّ، قَالَ مَا سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم جَمَعَ أَبَوَيْهِ لأَحَدٍ غَيْرَ سَعْدِ بْنِ أَبِي وَقَّاصٍ ‏.‏\hadithno{2828}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Ali:"I did not hear the Prophet (ﷺ) mentioning both of his parents (that is including both in the saying "May my father and mother be ransomed for you") for anyone other than Sa'd bin Abi Waqqas}}
\hadithdefcmd{tirmidhi}{2829}{حَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ الْبَزَّارُ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ جُدْعَانَ، وَيَحْيَى بْنِ سَعِيدٍ، سَمِعَا سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ قَالَ عَلِيٌّ مَا جَمَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَاهُ وَأُمَّهُ لأَحَدٍ إِلاَّ لِسَعْدِ بْنِ أَبِي وَقَّاصٍ قَالَ لَهُ يَوْمَ أُحُدٍ ‏"‏ ارْمِ فِدَاكَ أَبِي وَأُمِّي ‏"‏ ‏.‏ وَقَالَ لَهُ ‏"‏ ارْمِ أَيُّهَا الْغُلاَمُ الْحَزَوَّرُ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ الزُّبَيْرِ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ عَلِيٍّ ‏.‏\hadithno{2829}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ali:"The Messenger of Allah (ﷺ) did not mention both of his parents for anyone except Sa'd bin Abi Waqqas. On the Day of Uhud he said: 'Shoot, may my father and mother be ransomed for you.' And he said to him: 'Shoot! O young man}}
\hadithdefcmd{tirmidhi}{2830}{وَقَدْ رَوَى غَيْرُ، وَاحِدٍ، هَذَا الْحَدِيثَ عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَ جَمَعَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَوَيْهِ يَوْمَ أُحُدٍ قَالَ ‏ "‏ ارْمِ فِدَاكَ أَبِي وَأُمِّي ‏"‏ ‏.‏ حَدَّثَنَا بِذَلِكَ قُتَيْبَةُ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ وَعَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ عَنْ يَحْيَى بْنِ سَعِيدٍ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ قَالَ جَمَعَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَوَيْهِ يَوْمَ أُحُدٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَكِلاَ الْحَدِيثَيْنِ صَحِيحٌ ‏.‏\hadithno{2830}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Sa'd bin Abi Waqqas:"The Messenger of Allah (ﷺ) mentioned both of his parents to me on the Day of Uhud}}
\hadithdefcmd{tirmidhi}{2831}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا أَبُو عَوَانَةَ، حَدَّثَنَا أَبُو عُثْمَانَ، شَيْخٌ لَهُ عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ ‏ "‏ يَا بُنَىَّ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ الْمُغِيرَةِ وَعُمَرَ بْنِ أَبِي سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ أَنَسٍ ‏.‏ وَأَبُو عُثْمَانَ هَذَا شَيْخٌ ثِقَةٌ وَهُوَ الْجَعْدُ بْنُ عُثْمَانَ وَيُقَالُ ابْنُ دِينَارٍ وَهُوَ بَصْرِيٌّ وَقَدْ رَوَى عَنْهُ يُونُسُ بْنُ عُبَيْدٍ وَغَيْرُ وَاحِدٍ مِنَ الأَئِمَّةِ ‏.‏\hadithno{2831}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas:that the Prophet (ﷺ) said to him: "O my little son}}
\hadithdefcmd{tirmidhi}{2832}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ بْنِ سَعْدِ بْنِ إِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، حَدَّثَنِي عَمِّي، يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ حَدَّثَنَا شَرِيكٌ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ بِتَسْمِيَةِ الْمَوْلُودِ يَوْمَ سَابِعِهِ وَوَضْعِ الأَذَى عَنْهُ وَالْعَقِّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2832}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Amr bin Shu'aib:from his father, from his grandfather that the Prophet (ﷺ) ordered naming the child on the seventh day, removing the harm from him, and Al-'Aqq (removing the hair and slaughtering the animal for 'Aqiqah)}}
\hadithdefcmd{tirmidhi}{2833}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الأَسْوَدِ أَبُو عَمْرٍو الْوَرَّاقُ الْبَصْرِيُّ، حَدَّثَنَا مَعْمَرُ بْنُ سُلَيْمَانَ الرَّقِّيُّ، عَنْ عَلِيِّ بْنِ صَالِحٍ الْمَكِّيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَحَبُّ الأَسْمَاءِ إِلَى اللَّهِ عَزَّ وَجَلَّ عَبْدُ اللَّهِ وَعَبْدُ الرَّحْمَنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2833}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Umar:that the Prophet (ﷺ) said: "The most loved names to Allah are 'Abdullah and 'Abdur-Rahman}}
\hadithdefcmd{tirmidhi}{2834}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ الْعَمِّيُّ الْبَصْرِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ الْعُمَرِيِّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ أَحَبَّ الأَسْمَاءِ إِلَى اللَّهِ عَبْدُ اللَّهِ وَعَبْدُ الرَّحْمَنِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2834}\hadithgrade{Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Ibn 'Umar:that the Prophet (ﷺ) said: "The most loved names to Allah are 'Abdullah and 'Abdur-Rahman}}
\hadithdefcmd{tirmidhi}{2835}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْهَيَنَّ أَنْ يُسَمَّى رَافِعٌ وَبَرَكَةُ وَيَسَارٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ هَكَذَا رَوَاهُ أَبُو أَحْمَدَ عَنْ سُفْيَانَ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ عَنْ عُمَرَ وَرَوَاهُ غَيْرُهُ عَنْ سُفْيَانَ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَأَبُو أَحْمَدَ ثِقَةٌ حَافِظٌ وَالْمَشْهُورُ عِنْدَ النَّاسِ هَذَا الْحَدِيثُ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَيْسَ فِيهِ عَنْ عُمَرَ ‏.‏\hadithno{2835}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Umar [bin Al-Khattab]:that the Messenger of Allah (ﷺ) said: "I forbid naming with Rafi, Barakah and Yasar}}
\hadithdefcmd{tirmidhi}{2836}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، عَنْ شُعْبَةَ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنِ الرَّبِيعِ بْنِ عُمَيْلَةَ الْفَزَارِيِّ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُسَمِّي غُلاَمَكَ رَبَاحٌ وَلاَ أَفْلَحُ وَلاَ يَسَارٌ وَلاَ نَجِيحٌ يُقَالُ أَثَمَّ هُوَ فَيُقَالُ لاَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2836}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Samurah bin Jundab:that the Messenger of Allah (ﷺ) said: "Do not name your boy Rabah, nor Aflah, nor Yasar, nor Najih, so that it may be said: 'Is he there?' and it may be said: 'No}}
\hadithdefcmd{tirmidhi}{2837}{حَدَّثَنَا مُحَمَّدُ بْنُ مَيْمُونٍ الْمَكِّيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَخْنَعُ اسْمٍ عِنْدَ اللَّهِ يَوْمَ الْقِيَامَةِ رَجُلٌ تَسَمَّى بِمَلِكِ الأَمْلاَكِ ‏"‏ ‏.‏ قَالَ سُفْيَانُ شَاهَانْ شَاهْ وَأَخْنَعُ يَعْنِي أَقْبَحَ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2837}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Al-A'raj:that Abu Hurairah conveyed to him that the Prophet (ﷺ) said: "The most despicable (Akhna) name to Allah on the Day of Judgement is that of a man named King of Kings. (Malikil-Amlak)}}
\hadithdefcmd{tirmidhi}{2838}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، وَأَبُو بَكْرٍ مُحَمَّدُ بْنُ بَشَّارٍ وَغَيْرُ وَاحِدٍ قَالُوا حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم غَيَّرَ اسْمَ عَاصِيَةَ وَقَالَ ‏ "‏ أَنْتِ جَمِيلَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَإِنَّمَا أَسْنَدَهُ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ عَنْ عُبَيْدِ اللَّهِ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ وَرَوَى بَعْضُهُمْ هَذَا عَنْ عُبَيْدِ اللَّهِ عَنْ نَافِعٍ أَنَّ عُمَرَ ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَعَبْدِ اللَّهِ بْنِ سَلاَمٍ وَعَبْدِ اللَّهِ بْنِ مُطِيعٍ وَعَائِشَةَ وَالْحَكَمِ بْنِ سَعْدٍ وَمُسْلِمٍ وَأُسَامَةَ بْنِ أَخْدَرِيٍّ وَشُرَيْحِ بْنِ هَانِئٍ عَنْ أَبِيهِ وَخَيْثَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِيهِ ‏.‏\hadithno{2838}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Ibn 'Umar:that the Prophet (ﷺ) changed the name of 'Asiyah, he said: "You are Jamilah}}
\hadithdefcmd{tirmidhi}{2839}{حَدَّثَنَا أَبُو بَكْرِ بْنُ نَافِعٍ الْبَصْرِيُّ، حَدَّثَنَا عُمَرُ بْنُ عَلِيٍّ الْمُقَدَّمِيُّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُغَيِّرُ الاِسْمَ الْقَبِيحَ ‏.‏ قَالَ أَبُو بَكْرِ بْنُ نَافِعٍ وَرُبَّمَا قَالَ عُمَرُ بْنُ عَلِيٍّ فِي هَذَا الْحَدِيثِ هِشَامُ بْنُ عُرْوَةَ عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلٌ وَلَمْ يَذْكُرْ فِيهِ عَنْ عَائِشَةَ ‏.‏\hadithno{2839}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Aishah:that the Prophet (ﷺ) would change abhorrent names}}
\hadithdefcmd{tirmidhi}{2840}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ لِي أَسْمَاءً أَنَا مُحَمَّدٌ وَأَنَا أَحْمَدُ وَأَنَا الْمَاحِي الَّذِي يَمْحُو اللَّهُ بِيَ الْكُفْرَ وَأَنَا الْحَاشِرُ الَّذِي يُحْشَرُ النَّاسُ عَلَى قَدَمِي وَأَنَا الْعَاقِبُ الَّذِي لَيْسَ بَعْدِي نَبِيٌّ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ حُذَيْفَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2840}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Muhammad bin Jubair bin Mut'im:from his father that the Messenger of Allah (ﷺ) said: "I have some names: I am Muhammad, I am Ahmad, I am Al-Mahi, the one by whom Allah wipes out disbelief, I am Al-Hasir, the one whom the people are gathered at his feet, and I am Al-'Aqib, the one after whom there is no Prophet}}
\hadithdefcmd{tirmidhi}{2841}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يَجْمَعَ أَحَدٌ بَيْنَ اسْمِهِ وَكُنْيَتِهِ وَيُسَمَّى مُحَمَّدًا أَبَا الْقَاسِمِ ‏.‏ وَفِي الْبَابِ عَنْ جَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ كَرِهَ بَعْضُ أَهْلِ الْعِلْمِ أَنْ يَجْمَعَ الرَّجُلُ بَيْنَ اسْمِ النَّبِيِّ صلى الله عليه وسلم وَكُنْيَتِهِ وَقَدْ فَعَلَ ذَلِكَ بَعْضُهُمْ ‏.‏ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ سَمِعَ رَجُلاً، فِي السُّوقِ يُنَادِي يَا أَبَا الْقَاسِمِ فَالْتَفَتَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ لَمْ أَعْنِكَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَكْتَنُوا بِكُنْيَتِي ‏"‏ ‏.‏ حَدَّثَنَا بِذَلِكَ الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ عَنْ حُمَيْدٍ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا ‏.‏ وَفِي هَذَا الْحَدِيثِ مَا يَدُلُّ عَلَى كَرَاهِيَةِ أَنْ يُكْنَى أَبَا الْقَاسِمِ ‏.‏\hadithno{2841}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah:that the Prophet (ﷺ) prohibited that one use his name and his Kunyah; naming themselves Muhammad Abul-Qasim}}
\hadithdefcmd{tirmidhi}{2842}{حَدَّثَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنِ الْحُسَيْنِ بْنِ وَاقِدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا سَمَّيْتُمْ بِاسْمِي فَلاَ تَكْتَنُوا بِي ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2842}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Jabir:that the Messenger of Allah (ﷺ): "When you name yourself after me, then do not use my Kunyah}}
\hadithdefcmd{tirmidhi}{2843}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، حَدَّثَنَا فِطْرُ بْنُ خَلِيفَةَ، حَدَّثَنِي مُنْذِرٌ، وَهُوَ الثَّوْرِيُّ عَنْ مُحَمَّدِ ابْنِ الْحَنَفِيَّةِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ وُلِدَ لِي بَعْدَكَ أُسَمِّيهِ مُحَمَّدًا وَأُكْنِيهِ بِكُنْيَتِكَ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ قَالَ فَكَانَتْ رُخْصَةً لِي ‏.‏ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2843}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Ali bin Abi Talib:that he said: "O Messenger of Allah (ﷺ)! If I have a son after you do you think I could name him your Kunyah?" He said: "Yes." So he said: "So that was permitted for me}}
\hadithdefcmd{tirmidhi}{2844}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا يَحْيَى بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي غَنِيَّةَ، حَدَّثَنِي أَبِي، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنَ الشِّعْرِ حِكْمَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ إِنَّمَا رَفَعَهُ أَبُو سَعِيدٍ الأَشَجُّ عَنِ ابْنِ أَبِي غَنِيَّةَ ‏.‏ وَرَوَى غَيْرُهُ عَنِ ابْنِ أَبِي غَنِيَّةَ هَذَا الْحَدِيثَ مَوْقُوفًا ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَفِي الْبَابِ عَنْ أُبَىِّ بْنِ كَعْبٍ وَابْنِ عَبَّاسٍ وَعَائِشَةَ وَبُرَيْدَةَ وَكَثِيرِ بْنِ عَبْدِ اللَّهِ عَنْ أَبِيهِ عَنْ جَدِّهِ ‏.‏\hadithno{2844}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Abdullah:that the Messenger of Allah (ﷺ) said: "Indeed some poetry is wisdom}}
\hadithdefcmd{tirmidhi}{2845}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنَ الشِّعْرِ حُكْمًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2845}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn 'Abbas:that the Messenger of Allah (ﷺ) said: "Indeed some poetry is wisdom}}
\hadithdefcmd{tirmidhi}{2846}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى الْفَزَارِيُّ، وَعَلِيُّ بْنُ حُجْرٍ الْمَعْنَى، وَاحِدٌ، قَالاَ حَدَّثَنَا ابْنُ أَبِي الزِّنَادِ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَضَعُ لِحَسَّانَ مِنْبَرًا فِي الْمَسْجِدِ يَقُومُ عَلَيْهِ قَائِمًا يُفَاخِرُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم - أَوْ قَالَ يُنَافِحُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم - وَيَقُولُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يُؤَيِّدُ حَسَّانَ بِرُوحِ الْقُدُسِ مَا يُفَاخِرُ أَوْ يُنَافِحُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ ‏.‏\hadithno{2846}\hadithgrade{Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Aishah:"The Messenger of Allah (ﷺ) had a Minbar placed in the Masjid for Hassan to stand to boast (poetically) about the Messenger of Allah (ﷺ)" - or she said: "to defend the Messenger of Allah (ﷺ). And the Messenger of Allah (ﷺ) said: 'Indeed Allah has aided Hassan with the holy spirit (Jibril) as he boasts about - or - defends the Messenger of Allah (ﷺ)}}
\hadithdefcmd{tirmidhi}{2846p2}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى، وَعَلِيُّ بْنُ حُجْرٍ، قَالاَ حَدَّثَنَا ابْنُ أَبِي الزِّنَادِ، عَنْ أَبِيهِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَالْبَرَاءِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ وَهُوَ حَدِيثُ ابْنِ أَبِي الزِّنَادِ ‏.‏\hadithno{2846.2}\hadithtrans{(Another chain) from 'Aishah with the same narration}}
\hadithdefcmd{tirmidhi}{2847}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ مَكَّةَ فِي عُمْرَةِ الْقَضَاءِ وَعَبْدُ اللَّهِ بْنُ رَوَاحَةَ بَيْنَ يَدَيْهِ يَمْشِي وَهُوَ يَقُولُ خَلُّوا بَنِي الْكُفَّارِ عَنْ سَبِيلِهِ الْيَوْمَ نَضْرِبْكُمْ عَلَى تَنْزِيلِهِ ضَرْبًا يُزِيلُ الْهَامَ عَنْ مَقِيلِهِ وَيُذْهِلُ الْخَلِيلَ عَنْ خَلِيلِهِ فَقَالَ لَهُ عُمَرُ يَا ابْنَ رَوَاحَةَ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَفِي حَرَمِ اللَّهِ تَقُولُ الشِّعْرَ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ خَلِّ عَنْهُ يَا عُمَرُ فَلَهِيَ أَسْرَعُ فِيهِمْ مِنْ نَضْحِ النَّبْلِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رَوَى عَبْدُ الرَّزَّاقِ هَذَا الْحَدِيثَ أَيْضًا عَنْ مَعْمَرٍ عَنِ الزُّهْرِيِّ عَنْ أَنَسٍ نَحْوَ هَذَا وَرُوِيَ فِي غَيْرِ هَذَا الْحَدِيثِ أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ مَكَّةَ فِي عُمْرَةِ الْقَضَاءِ وَكَعْبُ بْنُ مَالِكٍ بَيْنَ يَدَيْهِ وَهَذَا أَصَحُّ عِنْدَ بَعْضِ أَهْلِ الْحَدِيثِ لأَنَّ عَبْدَ اللَّهِ بْنَ رَوَاحَةَ قُتِلَ يَوْمَ مُؤْتَةَ وَإِنَّمَا كَانَتْ عُمْرَةُ الْقَضَاءِ بَعْدَ ذَلِكَ ‏.‏\hadithno{2847}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas:that the Prophet (ﷺ) entered Makkah during 'Umratil-Qada and 'Abdullah bin Rawahah was walking in front of him reciting verses of poetry. "O tribes of disbelievers get out of his way - today we will strike you about its revelation; a strike that removes the heads from the shoulders - and makes the friend not concerned about his friend." 'Umar said to him: "O Ibn Rawahah! Before the Messenger of Allah (ﷺ), and in the sanctuary of Allah you utter poetry?" the Messenger of Allah (ﷺ) said: "Leave him O 'Umar! For it is quicker upon them than the raining arrow}}
\hadithdefcmd{tirmidhi}{2848}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا شَرِيكٌ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَ قِيلَ لَهَا هَلْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَتَمَثَّلُ بِشَيْءٍ مِنَ الشِّعْرِ قَالَتْ كَانَ يَتَمَثَّلُ بِشِعْرِ ابْنِ رَوَاحَةَ وَيَتَمَثَّلُ وَيَقُولُ ‏ "‏ وَيَأْتِيكَ بِالأَخْبَارِ مَنْ لَمْ تُزَوِّدِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2848}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Miqdam bin Shuraih:from his father, that 'Aishah was asked: "Did the Prophet (ﷺ) used to say any poetry?" She said: "He would say parables with the poetry of Ibn Rawahah, saying: 'News shall come to you from where you did not expect it}}
\hadithdefcmd{tirmidhi}{2849}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا شَرِيكٌ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَشْعَرُ كَلِمَةٍ تَكَلَّمَتْ بِهَا الْعَرَبُ كَلِمَةُ لَبِيدٍ أَلاَ كُلُّ شَيْءٍ مَا خَلاَ اللَّهَ بَاطِلُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ الثَّوْرِيُّ وَغَيْرُهُ عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ ‏.‏\hadithno{2849}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah:that the Prophet (ﷺ) said: "The best statement spoken by the Arab is the saying of Labid: 'Everything aside from Allah perishes}}
\hadithdefcmd{tirmidhi}{2850}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا شَرِيكٌ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ جَالَسْتُ النَّبِيَّ صلى الله عليه وسلم أَكْثَرَ مِنْ مِائَةِ مَرَّةٍ فَكَانَ أَصْحَابُهُ يَتَنَاشَدُونَ الشِّعْرَ وَيَتَذَاكَرُونَ أَشْيَاءَ مِنْ أَمْرِ الْجَاهِلِيَّةِ وَهُوَ سَاكِتٌ فَرُبَّمَا تَبَسَّمَ مَعَهُمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ زُهَيْرٌ عَنْ سِمَاكٍ أَيْضًا ‏.‏\hadithno{2850}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir bin Samurah:"I sat with the Prophet (ﷺ) more than one-hundred times. His Companions used to recite poetry and talk about things that occurred during Jahiliyyah, and he would remain silent, and sometimes he would smile along with them}}
\hadithdefcmd{tirmidhi}{2851}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، أَخْبَرَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ يُونُسَ بْنِ جُبَيْرٍ، عَنْ مُحَمَّدِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْ يَمْتَلِئَ جَوْفُ أَحَدِكُمْ قَيْحًا خَيْرٌ لَهُ مِنْ أَنْ يَمْتَلِئَ شِعْرًا ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2851}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Muhammad bin Sa'd bin Abi Waqqas:from his father that the Messenger of Allah (ﷺ) said: "It is better that one of you fill his insides with puss than to fill it with poetry}}
\hadithdefcmd{tirmidhi}{2852}{حَدَّثَنَا عِيسَى بْنُ عُثْمَانَ بْنِ عِيسَى الرَّمْلِيُّ، حَدَّثَنَا عَمِّي، يَحْيَى بْنُ عِيسَى الرَّمْلِيُّ عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْ يَمْتَلِئَ جَوْفُ أَحَدِكُمْ قَيْحًا يَرِيهُ خَيْرٌ مِنْ أَنْ يَمْتَلِئَ شِعْرًا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ سَعْدٍ وَابْنِ عُمَرَ وَأَبِي الدَّرْدَاءِ وَأَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2852}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "It is better that one of you fill his insides with puss than to fill it with poetry}}
\hadithdefcmd{tirmidhi}{2853}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، حَدَّثَنَا عُمَرُ بْنُ عَلِيٍّ الْمُقَدَّمِيُّ، حَدَّثَنَا نَافِعُ بْنُ عُمَرَ الْجُمَحِيُّ، عَنْ بِشْرِ بْنِ عَاصِمٍ، سَمِعَهُ يُحَدِّثُ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ يُبْغِضُ الْبَلِيغَ مِنَ الرِّجَالِ الَّذِي يَتَخَلَّلُ بِلِسَانِهِ كَمَا تَتَخَلَّلُ الْبَقَرَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَفِي الْبَابِ عَنْ سَعْدٍ ‏.‏\hadithno{2853}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Abdullah bin 'Amr:that the Messenger of Allah (ﷺ) said: "Indeed Allah detests the excessive among men, who slaps his tongue around like the cow slaps his tongue}}
\hadithdefcmd{tirmidhi}{2854}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ عَبْدِ الْجَبَّارِ بْنِ عُمَرَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَنَامَ الرَّجُلُ عَلَى سَطْحٍ لَيْسَ بِمَحْجُورٍ عَلَيْهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ مُحَمَّدِ بْنِ الْمُنْكَدِرِ عَنْ جَابِرٍ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَعَبْدُ الْجَبَّارِ بْنُ عُمَرَ الأَيْلِيُّ يُضَعَّفُ ‏.‏\hadithno{2854}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir:"The Messenger of Allah (ﷺ) prohibited that a man sleep on a terrace without something to obstruct him (so that he will not roll off and fall)}}
\hadithdefcmd{tirmidhi}{2855}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَخَوَّلُنَا بِالْمَوْعِظَةِ فِي الأَيَّامِ مَخَافَةَ السَّآمَةِ عَلَيْنَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2855}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah:"The Messenger of Allah (ﷺ) used to take care of us by preaching during the days fearing that we may get bored}}
\hadithdefcmd{tirmidhi}{2855p2}{\hadithno{2855.2}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{(Another chain) with similar meaning}}
\hadithdefcmd{tirmidhi}{2856}{حَدَّثَنَا أَبُو هِشَامٍ الرِّفَاعِيُّ، حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، قَالَ سُئِلَتْ عَائِشَةُ وَأُمُّ سَلَمَةَ أَىُّ الْعَمَلِ كَانَ أَحَبَّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتَا مَا دِيمَ عَلَيْهِ وَإِنْ قَلَّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2856}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Salih:"I asked 'Aishah and Umm Salamah about which deed did the Messenger of Allah (ﷺ) like to do most. They said: 'Whatever he could do regularly, even if it was little}}
\hadithdefcmd{tirmidhi}{2856p2}{وَقَدْ رُوِيَ عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ أَحَبُّ الْعَمَلِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مَا دِيمَ عَلَيْهِ ‏.‏ حَدَّثَنَا بِذَلِكَ هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ حَدَّثَنَا عَبْدَةُ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ بِمَعْنَاهُ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2856.2}\hadithgrade{Al-Albani: Sahih}\hadithtrans{It has been reported from Hisham bin 'Urwah from his father, that 'Aishah said:"The most loved deed to the Messenger of Allah (ﷺ) was what he could do regularly." (Another chain) with similar meaning}}
\hadithdefcmd{tirmidhi}{2857}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ كَثِيرِ بْنِ شِنْظِيرٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَمِّرُوا الآنِيَةَ وَأَوْكُوا الأَسْقِيَةَ وَأَجِيفُوا الأَبْوَابَ وَأَطْفِئُوا الْمَصَابِيحَ فَإِنَّ الْفُوَيْسِقَةَ رُبَّمَا جَرَّتِ الْفَتِيلَةَ فَأَحْرَقَتْ أَهْلَ الْبَيْتِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2857}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Jabir bin 'Abdullah:that the Messenger of Allah (ﷺ) said: "Cover the vessels, tie the water-skins, close the doors, extinguish the torches, for indeed the mischief-makers (vermin) may drag away the wick, causing a fire for the inhabitants of the house}}
\hadithdefcmd{tirmidhi}{2858}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَافَرْتُمْ فِي الْخِصْبِ فَأَعْطُوا الإِبِلَ حَظَّهَا مِنَ الأَرْضِ وَإِذَا سَافَرْتُمْ فِي السَّنَةِ فَبَادِرُوا بِنِقْيِهَا وَإِذَا عَرَّسْتُمْ فَاجْتَنِبُوا الطَّرِيقَ فَإِنَّهَا طُرُقُ الدَّوَابِّ وَمَأْوَى الْهَوَامِّ بِاللَّيْلِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ جَابِرٍ وَأَنَسٍ ‏.‏\hadithno{2858}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "When you travel through fertile land, then give the camels their fill of the land, and when you travel through drought, then hasten while they are fresh, and when you camp late, then stay away from the road, for indeed it is the route of the beasts and the abode of poisonous vermin in the night}}
